Package: Unicode
Version: 17.0.0-1
Encoding: UTF-8
Title: Unicode Data and Utilities
Authors@R: person("Kurt", "Hornik", role = c("aut", "cre"),
                  email = "Kurt.Hornik@R-project.org",
		  comment = c(ORCID = "0000-0003-4198-9911"))
Description: Data from Unicode 17.0.0 and related utilities.
Depends: R (>= 3.5.0)
Imports: utils
License: GPL-2
NeedsCompilation: no
Packaged: 2026-03-28 07:19:25 UTC; hornik
Author: Kurt Hornik [aut, cre] (ORCID: <https://orcid.org/0000-0003-4198-9911>)
Maintainer: Kurt Hornik <Kurt.Hornik@R-project.org>
Repository: CRAN
Date/Publication: 2026-03-28 07:26:35 UTC
Built: R 4.6.0; ; 2026-04-26 13:03:41 UTC; unix

importFrom("utils", "browseURL")

## basics.R

export("as.u_char", "as.u_char_range", "as.u_char_seq")

S3method("[", "u_char")
S3method("as.character", "u_char")
S3method("as.data.frame", "u_char")
S3method("as.integer", "u_char")
S3method("as.list", "u_char")
S3method("c", "u_char")
S3method("format", "u_char")
S3method("print", "u_char")
S3method("rep", "u_char")
S3method("unique", "u_char")

S3method("[", "u_char_range")
S3method("as.character", "u_char_range")
S3method("as.data.frame", "u_char_range")
S3method("c", "u_char_range")
S3method("format", "u_char_range")
S3method("print", "u_char_range")
S3method("rep", "u_char_range")
S3method("unique", "u_char_range")
S3method("unlist", "u_char_range")

S3method("[", "u_char_seq")
S3method("as.character", "u_char_seq")
S3method("as.data.frame", "u_char_seq")
S3method("c", "u_char_seq")
S3method("format", "u_char_seq")
S3method("print", "u_char_seq")
S3method("rep", "u_char_seq")
S3method("unique", "u_char_seq")
S3method("unlist", "u_char_seq")

export("n_of_u_chars")
S3method("n_of_u_chars", "u_char")
S3method("n_of_u_chars", "u_char_range")
S3method("n_of_u_chars", "u_char_seq")

export("u_char_match", "%uin%")

## casefuns.R

export("u_case_fold")
S3method("u_case_fold", "default")
S3method("u_case_fold", "u_char")
S3method("u_case_fold", "u_char_range")
S3method("u_case_fold", "u_char_seq")

export("u_to_lower_case")
S3method("u_to_lower_case", "default")
S3method("u_to_lower_case", "u_char")
S3method("u_to_lower_case", "u_char_range")
S3method("u_to_lower_case", "u_char_seq")

export("u_to_upper_case")
S3method("u_to_upper_case", "default")
S3method("u_to_upper_case", "u_char")
S3method("u_to_upper_case", "u_char_range")
S3method("u_to_upper_case", "u_char_seq")

export("u_to_title_case")
S3method("u_to_title_case", "u_char")

## charfuns.R

export("u_char_from_name",
       "u_char_info", 
       "u_char_inspect",
       "u_char_label",       
       "u_char_name",
       "u_char_properties",
       "u_char_property")

## strfuns.R

export("Unicode_alphabetic_tokenizer")

## ucdmisc.R

export("u_blocks", "u_named_sequences", "u_scripts")

These are experimental modules to handle various Unicode issues.  This
is software under construction.  Not even alpha state right now.

More information on Unicode can be found at http://www.unicode.org

Current modules are:

  Unicode::String   - represent strings of Unicode chars.
  Unicode::CharName - look up character names


Some of ideas to investigate for the Unicode modules are:

   o Fast encoding/decoding to various 8-bit char sets.  Mapping
     table objects perhaps?

   o Fast convertion to other large char sets (east-asien).  I don't
     know anything about this.

   o Composition/decomposition support:
     $u->decomp;  # will decomposite as much as possible:  "å"  --> "a°"
     $u->comp;    # will composite as much as possible:    "a°" --> "å"

     Need separate routines or a special argument to distinguish
     between compatibility decomposition and canonical decomposition.
     The last one is a subset of the first one.

   o General Unicode string to number convertion (based on unidata
     number attributes)

   o Case convertions (lc, uc, ucfirst)  last one should use title-case

   o Fast lookup of Unicode attributes (unidata lookup using XS)
     $u->isletter, $u->isupper, $u->islower,....  why do we need them when
     perl does not need them for normal text??

   o There might be some support for the private area (i.e. adding case
     convertion and char properties to chars within the area).

   o Unicode tr-function, sprintf-function

   o Unicode string comparison functions: cmp(), le, eq,...

   o Unicode regular expressions: m// s/// split(//,..)

   o Unicode filehandles (automatic convertion from UTF-7/UTF-8/8-bit 
     char set when reading,writing to filehandles)


The following are examples of use of the current modules:

   use Unicode::String qw(latin1 utf8);

   $u = utf8("this is a string\n");
   print $u->ucs4;
   print $u->utf16;
   print $u->utf8;
   print $u->utf7;
   print $u->latin1;
   print $u->hex;

   print latin1("naïve\n")->utf8;

   use Unicode::CharName qw(uname);
   print uname(ord('$')), "\n";



COPYRIGHT

  © 1997 Gisle Aas. All rights reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

# Unicode v9.0.0 data

JavaScript-compatible Unicode data for use in Node.js. Included: arrays of code points, arrays of symbols, and regular expressions for Unicode v9.0.0’s categories, scripts, script extensions, blocks, and properties, as well as bidi mirroring and case folding data.

The data files in this module are generated as part of the [node-unicode-data](https://mths.be/node-unicode-data) project. **Please report any bugs or requests [in the appropriate issue tracker](https://github.com/mathiasbynens/node-unicode-data/issues).**

## Installation

```bash
npm install unicode-9.0.0 --save-dev
```

**Note:** _unicode-9.0.0_ is supposed to be used in build scripts (i.e. as a `devDependency`), and not at runtime (i.e. as a regular `dependency`).

## Regular expressions

The Unicode data modules ship with pre-compiled regular expressions for categories, scripts, script extensions, blocks, and properties. But maybe you want to create a single regular expression that combines several categories, scripts, etc. In that case, [***you should use Regenerate***](https://mths.be/regenerate). For example, to construct a regex that matches all symbols in the Arabic and Greek scripts as per Unicode v6.3.0:

```js
const regenerate = require('regenerate');
const set = regenerate()
  .add(require('unicode-6.3.0/Script_Extensions/Arabic/code-points')) // or `…/symbols`, doesn’t matter
  .add(require('unicode-6.3.0/Script_Extensions/Greek/code-points')); // or `…/symbols`, doesn’t matter
console.log(set.toString());
// Then you might want to use a template like this to write the result to a file, along with any regex flags you might need:
// const regex = /<%= set.toString() %>/gim;
```

## Usage

```js
// Get an array of code points in a given Unicode category:
const codePoints = require('unicode-9.0.0/General_Category/Uppercase_Letter/code-points');
// Get an array of symbols (strings) in a given Unicode category:
const symbols = require('unicode-9.0.0/General_Category/Uppercase_Letter/symbols');
// Get a regular expression that matches any symbol in a given Unicode category:
const regex = require('unicode-9.0.0/General_Category/Uppercase_Letter/regex');
// Get the canonical category a given code point belongs to:
// (Note: U+0041 is LATIN CAPITAL LETTER A)
const category = require('unicode-9.0.0/General_Category').get(0x41);
// Get an array of all code points with a given bidi class:
const on = require('unicode-9.0.0/Bidi_Class/Other_Neutral/code-points');
// Get a map from code points to bidi classes:
const bidiClassMap = require('unicode-9.0.0/Bidi_Class');
// Get the directionality of a given code point:
const directionality = require('unicode-9.0.0/Bidi_Class').get(0x41);

// What glyph is the mirror image of `«` (U+00AB)?
const mirrored = require('unicode-9.0.0/Bidi_Mirroring_Glyph').get(0xAB);

// Get a regular expression that matches all opening brackets:
const openingBrackets = require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Open/regex');

// …you get the idea.
```

Other than categories, data on Unicode properties, blocks, scripts, and script extensions is available too (for recent versions of the Unicode standard). Here’s the full list of the available data for v9.0.0:

```js
// `Binary_Property`:

require('unicode-9.0.0/Binary_Property/ASCII/code-points');
require('unicode-9.0.0/Binary_Property/ASCII/symbols');
require('unicode-9.0.0/Binary_Property/ASCII/regex');

require('unicode-9.0.0/Binary_Property/ASCII_Hex_Digit/code-points');
require('unicode-9.0.0/Binary_Property/ASCII_Hex_Digit/symbols');
require('unicode-9.0.0/Binary_Property/ASCII_Hex_Digit/regex');

require('unicode-9.0.0/Binary_Property/Alphabetic/code-points');
require('unicode-9.0.0/Binary_Property/Alphabetic/symbols');
require('unicode-9.0.0/Binary_Property/Alphabetic/regex');

require('unicode-9.0.0/Binary_Property/Any/code-points');
require('unicode-9.0.0/Binary_Property/Any/symbols');
require('unicode-9.0.0/Binary_Property/Any/regex');

require('unicode-9.0.0/Binary_Property/Assigned/code-points');
require('unicode-9.0.0/Binary_Property/Assigned/symbols');
require('unicode-9.0.0/Binary_Property/Assigned/regex');

require('unicode-9.0.0/Binary_Property/Bidi_Control/code-points');
require('unicode-9.0.0/Binary_Property/Bidi_Control/symbols');
require('unicode-9.0.0/Binary_Property/Bidi_Control/regex');

require('unicode-9.0.0/Binary_Property/Bidi_Mirrored/code-points');
require('unicode-9.0.0/Binary_Property/Bidi_Mirrored/symbols');
require('unicode-9.0.0/Binary_Property/Bidi_Mirrored/regex');

require('unicode-9.0.0/Binary_Property/Case_Ignorable/code-points');
require('unicode-9.0.0/Binary_Property/Case_Ignorable/symbols');
require('unicode-9.0.0/Binary_Property/Case_Ignorable/regex');

require('unicode-9.0.0/Binary_Property/Cased/code-points');
require('unicode-9.0.0/Binary_Property/Cased/symbols');
require('unicode-9.0.0/Binary_Property/Cased/regex');

require('unicode-9.0.0/Binary_Property/Changes_When_Casefolded/code-points');
require('unicode-9.0.0/Binary_Property/Changes_When_Casefolded/symbols');
require('unicode-9.0.0/Binary_Property/Changes_When_Casefolded/regex');

require('unicode-9.0.0/Binary_Property/Changes_When_Casemapped/code-points');
require('unicode-9.0.0/Binary_Property/Changes_When_Casemapped/symbols');
require('unicode-9.0.0/Binary_Property/Changes_When_Casemapped/regex');

require('unicode-9.0.0/Binary_Property/Changes_When_Lowercased/code-points');
require('unicode-9.0.0/Binary_Property/Changes_When_Lowercased/symbols');
require('unicode-9.0.0/Binary_Property/Changes_When_Lowercased/regex');

require('unicode-9.0.0/Binary_Property/Changes_When_NFKC_Casefolded/code-points');
require('unicode-9.0.0/Binary_Property/Changes_When_NFKC_Casefolded/symbols');
require('unicode-9.0.0/Binary_Property/Changes_When_NFKC_Casefolded/regex');

require('unicode-9.0.0/Binary_Property/Changes_When_Titlecased/code-points');
require('unicode-9.0.0/Binary_Property/Changes_When_Titlecased/symbols');
require('unicode-9.0.0/Binary_Property/Changes_When_Titlecased/regex');

require('unicode-9.0.0/Binary_Property/Changes_When_Uppercased/code-points');
require('unicode-9.0.0/Binary_Property/Changes_When_Uppercased/symbols');
require('unicode-9.0.0/Binary_Property/Changes_When_Uppercased/regex');

require('unicode-9.0.0/Binary_Property/Composition_Exclusion/code-points');
require('unicode-9.0.0/Binary_Property/Composition_Exclusion/symbols');
require('unicode-9.0.0/Binary_Property/Composition_Exclusion/regex');

require('unicode-9.0.0/Binary_Property/Dash/code-points');
require('unicode-9.0.0/Binary_Property/Dash/symbols');
require('unicode-9.0.0/Binary_Property/Dash/regex');

require('unicode-9.0.0/Binary_Property/Default_Ignorable_Code_Point/code-points');
require('unicode-9.0.0/Binary_Property/Default_Ignorable_Code_Point/symbols');
require('unicode-9.0.0/Binary_Property/Default_Ignorable_Code_Point/regex');

require('unicode-9.0.0/Binary_Property/Deprecated/code-points');
require('unicode-9.0.0/Binary_Property/Deprecated/symbols');
require('unicode-9.0.0/Binary_Property/Deprecated/regex');

require('unicode-9.0.0/Binary_Property/Diacritic/code-points');
require('unicode-9.0.0/Binary_Property/Diacritic/symbols');
require('unicode-9.0.0/Binary_Property/Diacritic/regex');

require('unicode-9.0.0/Binary_Property/Expands_On_NFC/code-points');
require('unicode-9.0.0/Binary_Property/Expands_On_NFC/symbols');
require('unicode-9.0.0/Binary_Property/Expands_On_NFC/regex');

require('unicode-9.0.0/Binary_Property/Expands_On_NFD/code-points');
require('unicode-9.0.0/Binary_Property/Expands_On_NFD/symbols');
require('unicode-9.0.0/Binary_Property/Expands_On_NFD/regex');

require('unicode-9.0.0/Binary_Property/Expands_On_NFKC/code-points');
require('unicode-9.0.0/Binary_Property/Expands_On_NFKC/symbols');
require('unicode-9.0.0/Binary_Property/Expands_On_NFKC/regex');

require('unicode-9.0.0/Binary_Property/Expands_On_NFKD/code-points');
require('unicode-9.0.0/Binary_Property/Expands_On_NFKD/symbols');
require('unicode-9.0.0/Binary_Property/Expands_On_NFKD/regex');

require('unicode-9.0.0/Binary_Property/Extender/code-points');
require('unicode-9.0.0/Binary_Property/Extender/symbols');
require('unicode-9.0.0/Binary_Property/Extender/regex');

require('unicode-9.0.0/Binary_Property/FC_NFKC_Closure/code-points');
require('unicode-9.0.0/Binary_Property/FC_NFKC_Closure/symbols');
require('unicode-9.0.0/Binary_Property/FC_NFKC_Closure/regex');

require('unicode-9.0.0/Binary_Property/Full_Composition_Exclusion/code-points');
require('unicode-9.0.0/Binary_Property/Full_Composition_Exclusion/symbols');
require('unicode-9.0.0/Binary_Property/Full_Composition_Exclusion/regex');

require('unicode-9.0.0/Binary_Property/Grapheme_Base/code-points');
require('unicode-9.0.0/Binary_Property/Grapheme_Base/symbols');
require('unicode-9.0.0/Binary_Property/Grapheme_Base/regex');

require('unicode-9.0.0/Binary_Property/Grapheme_Extend/code-points');
require('unicode-9.0.0/Binary_Property/Grapheme_Extend/symbols');
require('unicode-9.0.0/Binary_Property/Grapheme_Extend/regex');

require('unicode-9.0.0/Binary_Property/Grapheme_Link/code-points');
require('unicode-9.0.0/Binary_Property/Grapheme_Link/symbols');
require('unicode-9.0.0/Binary_Property/Grapheme_Link/regex');

require('unicode-9.0.0/Binary_Property/Hex_Digit/code-points');
require('unicode-9.0.0/Binary_Property/Hex_Digit/symbols');
require('unicode-9.0.0/Binary_Property/Hex_Digit/regex');

require('unicode-9.0.0/Binary_Property/Hyphen/code-points');
require('unicode-9.0.0/Binary_Property/Hyphen/symbols');
require('unicode-9.0.0/Binary_Property/Hyphen/regex');

require('unicode-9.0.0/Binary_Property/IDS_Binary_Operator/code-points');
require('unicode-9.0.0/Binary_Property/IDS_Binary_Operator/symbols');
require('unicode-9.0.0/Binary_Property/IDS_Binary_Operator/regex');

require('unicode-9.0.0/Binary_Property/IDS_Trinary_Operator/code-points');
require('unicode-9.0.0/Binary_Property/IDS_Trinary_Operator/symbols');
require('unicode-9.0.0/Binary_Property/IDS_Trinary_Operator/regex');

require('unicode-9.0.0/Binary_Property/ID_Continue/code-points');
require('unicode-9.0.0/Binary_Property/ID_Continue/symbols');
require('unicode-9.0.0/Binary_Property/ID_Continue/regex');

require('unicode-9.0.0/Binary_Property/ID_Start/code-points');
require('unicode-9.0.0/Binary_Property/ID_Start/symbols');
require('unicode-9.0.0/Binary_Property/ID_Start/regex');

require('unicode-9.0.0/Binary_Property/Ideographic/code-points');
require('unicode-9.0.0/Binary_Property/Ideographic/symbols');
require('unicode-9.0.0/Binary_Property/Ideographic/regex');

require('unicode-9.0.0/Binary_Property/Join_Control/code-points');
require('unicode-9.0.0/Binary_Property/Join_Control/symbols');
require('unicode-9.0.0/Binary_Property/Join_Control/regex');

require('unicode-9.0.0/Binary_Property/Logical_Order_Exception/code-points');
require('unicode-9.0.0/Binary_Property/Logical_Order_Exception/symbols');
require('unicode-9.0.0/Binary_Property/Logical_Order_Exception/regex');

require('unicode-9.0.0/Binary_Property/Lowercase/code-points');
require('unicode-9.0.0/Binary_Property/Lowercase/symbols');
require('unicode-9.0.0/Binary_Property/Lowercase/regex');

require('unicode-9.0.0/Binary_Property/Math/code-points');
require('unicode-9.0.0/Binary_Property/Math/symbols');
require('unicode-9.0.0/Binary_Property/Math/regex');

require('unicode-9.0.0/Binary_Property/Noncharacter_Code_Point/code-points');
require('unicode-9.0.0/Binary_Property/Noncharacter_Code_Point/symbols');
require('unicode-9.0.0/Binary_Property/Noncharacter_Code_Point/regex');

require('unicode-9.0.0/Binary_Property/Other_Alphabetic/code-points');
require('unicode-9.0.0/Binary_Property/Other_Alphabetic/symbols');
require('unicode-9.0.0/Binary_Property/Other_Alphabetic/regex');

require('unicode-9.0.0/Binary_Property/Other_Default_Ignorable_Code_Point/code-points');
require('unicode-9.0.0/Binary_Property/Other_Default_Ignorable_Code_Point/symbols');
require('unicode-9.0.0/Binary_Property/Other_Default_Ignorable_Code_Point/regex');

require('unicode-9.0.0/Binary_Property/Other_Grapheme_Extend/code-points');
require('unicode-9.0.0/Binary_Property/Other_Grapheme_Extend/symbols');
require('unicode-9.0.0/Binary_Property/Other_Grapheme_Extend/regex');

require('unicode-9.0.0/Binary_Property/Other_ID_Continue/code-points');
require('unicode-9.0.0/Binary_Property/Other_ID_Continue/symbols');
require('unicode-9.0.0/Binary_Property/Other_ID_Continue/regex');

require('unicode-9.0.0/Binary_Property/Other_ID_Start/code-points');
require('unicode-9.0.0/Binary_Property/Other_ID_Start/symbols');
require('unicode-9.0.0/Binary_Property/Other_ID_Start/regex');

require('unicode-9.0.0/Binary_Property/Other_Lowercase/code-points');
require('unicode-9.0.0/Binary_Property/Other_Lowercase/symbols');
require('unicode-9.0.0/Binary_Property/Other_Lowercase/regex');

require('unicode-9.0.0/Binary_Property/Other_Math/code-points');
require('unicode-9.0.0/Binary_Property/Other_Math/symbols');
require('unicode-9.0.0/Binary_Property/Other_Math/regex');

require('unicode-9.0.0/Binary_Property/Other_Uppercase/code-points');
require('unicode-9.0.0/Binary_Property/Other_Uppercase/symbols');
require('unicode-9.0.0/Binary_Property/Other_Uppercase/regex');

require('unicode-9.0.0/Binary_Property/Pattern_Syntax/code-points');
require('unicode-9.0.0/Binary_Property/Pattern_Syntax/symbols');
require('unicode-9.0.0/Binary_Property/Pattern_Syntax/regex');

require('unicode-9.0.0/Binary_Property/Pattern_White_Space/code-points');
require('unicode-9.0.0/Binary_Property/Pattern_White_Space/symbols');
require('unicode-9.0.0/Binary_Property/Pattern_White_Space/regex');

require('unicode-9.0.0/Binary_Property/Prepended_Concatenation_Mark/code-points');
require('unicode-9.0.0/Binary_Property/Prepended_Concatenation_Mark/symbols');
require('unicode-9.0.0/Binary_Property/Prepended_Concatenation_Mark/regex');

require('unicode-9.0.0/Binary_Property/Quotation_Mark/code-points');
require('unicode-9.0.0/Binary_Property/Quotation_Mark/symbols');
require('unicode-9.0.0/Binary_Property/Quotation_Mark/regex');

require('unicode-9.0.0/Binary_Property/Radical/code-points');
require('unicode-9.0.0/Binary_Property/Radical/symbols');
require('unicode-9.0.0/Binary_Property/Radical/regex');

require('unicode-9.0.0/Binary_Property/Sentence_Terminal/code-points');
require('unicode-9.0.0/Binary_Property/Sentence_Terminal/symbols');
require('unicode-9.0.0/Binary_Property/Sentence_Terminal/regex');

require('unicode-9.0.0/Binary_Property/Soft_Dotted/code-points');
require('unicode-9.0.0/Binary_Property/Soft_Dotted/symbols');
require('unicode-9.0.0/Binary_Property/Soft_Dotted/regex');

require('unicode-9.0.0/Binary_Property/Terminal_Punctuation/code-points');
require('unicode-9.0.0/Binary_Property/Terminal_Punctuation/symbols');
require('unicode-9.0.0/Binary_Property/Terminal_Punctuation/regex');

require('unicode-9.0.0/Binary_Property/Unified_Ideograph/code-points');
require('unicode-9.0.0/Binary_Property/Unified_Ideograph/symbols');
require('unicode-9.0.0/Binary_Property/Unified_Ideograph/regex');

require('unicode-9.0.0/Binary_Property/Uppercase/code-points');
require('unicode-9.0.0/Binary_Property/Uppercase/symbols');
require('unicode-9.0.0/Binary_Property/Uppercase/regex');

require('unicode-9.0.0/Binary_Property/Variation_Selector/code-points');
require('unicode-9.0.0/Binary_Property/Variation_Selector/symbols');
require('unicode-9.0.0/Binary_Property/Variation_Selector/regex');

require('unicode-9.0.0/Binary_Property/White_Space/code-points');
require('unicode-9.0.0/Binary_Property/White_Space/symbols');
require('unicode-9.0.0/Binary_Property/White_Space/regex');

require('unicode-9.0.0/Binary_Property/XID_Continue/code-points');
require('unicode-9.0.0/Binary_Property/XID_Continue/symbols');
require('unicode-9.0.0/Binary_Property/XID_Continue/regex');

require('unicode-9.0.0/Binary_Property/XID_Start/code-points');
require('unicode-9.0.0/Binary_Property/XID_Start/symbols');
require('unicode-9.0.0/Binary_Property/XID_Start/regex');

// `General_Category`:

require('unicode-9.0.0/General_Category').get(codePoint); // lookup map

require('unicode-9.0.0/General_Category/Cased_Letter/code-points');
require('unicode-9.0.0/General_Category/Cased_Letter/symbols');
require('unicode-9.0.0/General_Category/Cased_Letter/regex');

require('unicode-9.0.0/General_Category/Close_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Close_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Close_Punctuation/regex');

require('unicode-9.0.0/General_Category/Connector_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Connector_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Connector_Punctuation/regex');

require('unicode-9.0.0/General_Category/Control/code-points');
require('unicode-9.0.0/General_Category/Control/symbols');
require('unicode-9.0.0/General_Category/Control/regex');

require('unicode-9.0.0/General_Category/Currency_Symbol/code-points');
require('unicode-9.0.0/General_Category/Currency_Symbol/symbols');
require('unicode-9.0.0/General_Category/Currency_Symbol/regex');

require('unicode-9.0.0/General_Category/Dash_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Dash_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Dash_Punctuation/regex');

require('unicode-9.0.0/General_Category/Decimal_Number/code-points');
require('unicode-9.0.0/General_Category/Decimal_Number/symbols');
require('unicode-9.0.0/General_Category/Decimal_Number/regex');

require('unicode-9.0.0/General_Category/Enclosing_Mark/code-points');
require('unicode-9.0.0/General_Category/Enclosing_Mark/symbols');
require('unicode-9.0.0/General_Category/Enclosing_Mark/regex');

require('unicode-9.0.0/General_Category/Final_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Final_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Final_Punctuation/regex');

require('unicode-9.0.0/General_Category/Format/code-points');
require('unicode-9.0.0/General_Category/Format/symbols');
require('unicode-9.0.0/General_Category/Format/regex');

require('unicode-9.0.0/General_Category/Initial_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Initial_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Initial_Punctuation/regex');

require('unicode-9.0.0/General_Category/Letter/code-points');
require('unicode-9.0.0/General_Category/Letter/symbols');
require('unicode-9.0.0/General_Category/Letter/regex');

require('unicode-9.0.0/General_Category/Letter_Number/code-points');
require('unicode-9.0.0/General_Category/Letter_Number/symbols');
require('unicode-9.0.0/General_Category/Letter_Number/regex');

require('unicode-9.0.0/General_Category/Line_Separator/code-points');
require('unicode-9.0.0/General_Category/Line_Separator/symbols');
require('unicode-9.0.0/General_Category/Line_Separator/regex');

require('unicode-9.0.0/General_Category/Lowercase_Letter/code-points');
require('unicode-9.0.0/General_Category/Lowercase_Letter/symbols');
require('unicode-9.0.0/General_Category/Lowercase_Letter/regex');

require('unicode-9.0.0/General_Category/Mark/code-points');
require('unicode-9.0.0/General_Category/Mark/symbols');
require('unicode-9.0.0/General_Category/Mark/regex');

require('unicode-9.0.0/General_Category/Math_Symbol/code-points');
require('unicode-9.0.0/General_Category/Math_Symbol/symbols');
require('unicode-9.0.0/General_Category/Math_Symbol/regex');

require('unicode-9.0.0/General_Category/Modifier_Letter/code-points');
require('unicode-9.0.0/General_Category/Modifier_Letter/symbols');
require('unicode-9.0.0/General_Category/Modifier_Letter/regex');

require('unicode-9.0.0/General_Category/Modifier_Symbol/code-points');
require('unicode-9.0.0/General_Category/Modifier_Symbol/symbols');
require('unicode-9.0.0/General_Category/Modifier_Symbol/regex');

require('unicode-9.0.0/General_Category/Nonspacing_Mark/code-points');
require('unicode-9.0.0/General_Category/Nonspacing_Mark/symbols');
require('unicode-9.0.0/General_Category/Nonspacing_Mark/regex');

require('unicode-9.0.0/General_Category/Number/code-points');
require('unicode-9.0.0/General_Category/Number/symbols');
require('unicode-9.0.0/General_Category/Number/regex');

require('unicode-9.0.0/General_Category/Open_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Open_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Open_Punctuation/regex');

require('unicode-9.0.0/General_Category/Other/code-points');
require('unicode-9.0.0/General_Category/Other/symbols');
require('unicode-9.0.0/General_Category/Other/regex');

require('unicode-9.0.0/General_Category/Other_Letter/code-points');
require('unicode-9.0.0/General_Category/Other_Letter/symbols');
require('unicode-9.0.0/General_Category/Other_Letter/regex');

require('unicode-9.0.0/General_Category/Other_Number/code-points');
require('unicode-9.0.0/General_Category/Other_Number/symbols');
require('unicode-9.0.0/General_Category/Other_Number/regex');

require('unicode-9.0.0/General_Category/Other_Punctuation/code-points');
require('unicode-9.0.0/General_Category/Other_Punctuation/symbols');
require('unicode-9.0.0/General_Category/Other_Punctuation/regex');

require('unicode-9.0.0/General_Category/Other_Symbol/code-points');
require('unicode-9.0.0/General_Category/Other_Symbol/symbols');
require('unicode-9.0.0/General_Category/Other_Symbol/regex');

require('unicode-9.0.0/General_Category/Paragraph_Separator/code-points');
require('unicode-9.0.0/General_Category/Paragraph_Separator/symbols');
require('unicode-9.0.0/General_Category/Paragraph_Separator/regex');

require('unicode-9.0.0/General_Category/Private_Use/code-points');
require('unicode-9.0.0/General_Category/Private_Use/symbols');
require('unicode-9.0.0/General_Category/Private_Use/regex');

require('unicode-9.0.0/General_Category/Punctuation/code-points');
require('unicode-9.0.0/General_Category/Punctuation/symbols');
require('unicode-9.0.0/General_Category/Punctuation/regex');

require('unicode-9.0.0/General_Category/Separator/code-points');
require('unicode-9.0.0/General_Category/Separator/symbols');
require('unicode-9.0.0/General_Category/Separator/regex');

require('unicode-9.0.0/General_Category/Space_Separator/code-points');
require('unicode-9.0.0/General_Category/Space_Separator/symbols');
require('unicode-9.0.0/General_Category/Space_Separator/regex');

require('unicode-9.0.0/General_Category/Spacing_Mark/code-points');
require('unicode-9.0.0/General_Category/Spacing_Mark/symbols');
require('unicode-9.0.0/General_Category/Spacing_Mark/regex');

require('unicode-9.0.0/General_Category/Surrogate/code-points');
require('unicode-9.0.0/General_Category/Surrogate/symbols');
require('unicode-9.0.0/General_Category/Surrogate/regex');

require('unicode-9.0.0/General_Category/Symbol/code-points');
require('unicode-9.0.0/General_Category/Symbol/symbols');
require('unicode-9.0.0/General_Category/Symbol/regex');

require('unicode-9.0.0/General_Category/Titlecase_Letter/code-points');
require('unicode-9.0.0/General_Category/Titlecase_Letter/symbols');
require('unicode-9.0.0/General_Category/Titlecase_Letter/regex');

require('unicode-9.0.0/General_Category/Unassigned/code-points');
require('unicode-9.0.0/General_Category/Unassigned/symbols');
require('unicode-9.0.0/General_Category/Unassigned/regex');

require('unicode-9.0.0/General_Category/Uppercase_Letter/code-points');
require('unicode-9.0.0/General_Category/Uppercase_Letter/symbols');
require('unicode-9.0.0/General_Category/Uppercase_Letter/regex');

// `Bidi_Class`:

require('unicode-9.0.0/Bidi_Class').get(codePoint); // lookup map

require('unicode-9.0.0/Bidi_Class/Arabic_Letter/code-points');
require('unicode-9.0.0/Bidi_Class/Arabic_Letter/symbols');
require('unicode-9.0.0/Bidi_Class/Arabic_Letter/regex');

require('unicode-9.0.0/Bidi_Class/Arabic_Number/code-points');
require('unicode-9.0.0/Bidi_Class/Arabic_Number/symbols');
require('unicode-9.0.0/Bidi_Class/Arabic_Number/regex');

require('unicode-9.0.0/Bidi_Class/Boundary_Neutral/code-points');
require('unicode-9.0.0/Bidi_Class/Boundary_Neutral/symbols');
require('unicode-9.0.0/Bidi_Class/Boundary_Neutral/regex');

require('unicode-9.0.0/Bidi_Class/Common_Separator/code-points');
require('unicode-9.0.0/Bidi_Class/Common_Separator/symbols');
require('unicode-9.0.0/Bidi_Class/Common_Separator/regex');

require('unicode-9.0.0/Bidi_Class/European_Number/code-points');
require('unicode-9.0.0/Bidi_Class/European_Number/symbols');
require('unicode-9.0.0/Bidi_Class/European_Number/regex');

require('unicode-9.0.0/Bidi_Class/European_Separator/code-points');
require('unicode-9.0.0/Bidi_Class/European_Separator/symbols');
require('unicode-9.0.0/Bidi_Class/European_Separator/regex');

require('unicode-9.0.0/Bidi_Class/European_Terminator/code-points');
require('unicode-9.0.0/Bidi_Class/European_Terminator/symbols');
require('unicode-9.0.0/Bidi_Class/European_Terminator/regex');

require('unicode-9.0.0/Bidi_Class/First_Strong_Isolate/code-points');
require('unicode-9.0.0/Bidi_Class/First_Strong_Isolate/symbols');
require('unicode-9.0.0/Bidi_Class/First_Strong_Isolate/regex');

require('unicode-9.0.0/Bidi_Class/Left_To_Right/code-points');
require('unicode-9.0.0/Bidi_Class/Left_To_Right/symbols');
require('unicode-9.0.0/Bidi_Class/Left_To_Right/regex');

require('unicode-9.0.0/Bidi_Class/Left_To_Right_Embedding/code-points');
require('unicode-9.0.0/Bidi_Class/Left_To_Right_Embedding/symbols');
require('unicode-9.0.0/Bidi_Class/Left_To_Right_Embedding/regex');

require('unicode-9.0.0/Bidi_Class/Left_To_Right_Isolate/code-points');
require('unicode-9.0.0/Bidi_Class/Left_To_Right_Isolate/symbols');
require('unicode-9.0.0/Bidi_Class/Left_To_Right_Isolate/regex');

require('unicode-9.0.0/Bidi_Class/Left_To_Right_Override/code-points');
require('unicode-9.0.0/Bidi_Class/Left_To_Right_Override/symbols');
require('unicode-9.0.0/Bidi_Class/Left_To_Right_Override/regex');

require('unicode-9.0.0/Bidi_Class/Nonspacing_Mark/code-points');
require('unicode-9.0.0/Bidi_Class/Nonspacing_Mark/symbols');
require('unicode-9.0.0/Bidi_Class/Nonspacing_Mark/regex');

require('unicode-9.0.0/Bidi_Class/Other_Neutral/code-points');
require('unicode-9.0.0/Bidi_Class/Other_Neutral/symbols');
require('unicode-9.0.0/Bidi_Class/Other_Neutral/regex');

require('unicode-9.0.0/Bidi_Class/Paragraph_Separator/code-points');
require('unicode-9.0.0/Bidi_Class/Paragraph_Separator/symbols');
require('unicode-9.0.0/Bidi_Class/Paragraph_Separator/regex');

require('unicode-9.0.0/Bidi_Class/Pop_Directional_Format/code-points');
require('unicode-9.0.0/Bidi_Class/Pop_Directional_Format/symbols');
require('unicode-9.0.0/Bidi_Class/Pop_Directional_Format/regex');

require('unicode-9.0.0/Bidi_Class/Pop_Directional_Isolate/code-points');
require('unicode-9.0.0/Bidi_Class/Pop_Directional_Isolate/symbols');
require('unicode-9.0.0/Bidi_Class/Pop_Directional_Isolate/regex');

require('unicode-9.0.0/Bidi_Class/Right_To_Left/code-points');
require('unicode-9.0.0/Bidi_Class/Right_To_Left/symbols');
require('unicode-9.0.0/Bidi_Class/Right_To_Left/regex');

require('unicode-9.0.0/Bidi_Class/Right_To_Left_Embedding/code-points');
require('unicode-9.0.0/Bidi_Class/Right_To_Left_Embedding/symbols');
require('unicode-9.0.0/Bidi_Class/Right_To_Left_Embedding/regex');

require('unicode-9.0.0/Bidi_Class/Right_To_Left_Isolate/code-points');
require('unicode-9.0.0/Bidi_Class/Right_To_Left_Isolate/symbols');
require('unicode-9.0.0/Bidi_Class/Right_To_Left_Isolate/regex');

require('unicode-9.0.0/Bidi_Class/Right_To_Left_Override/code-points');
require('unicode-9.0.0/Bidi_Class/Right_To_Left_Override/symbols');
require('unicode-9.0.0/Bidi_Class/Right_To_Left_Override/regex');

require('unicode-9.0.0/Bidi_Class/Segment_Separator/code-points');
require('unicode-9.0.0/Bidi_Class/Segment_Separator/symbols');
require('unicode-9.0.0/Bidi_Class/Segment_Separator/regex');

require('unicode-9.0.0/Bidi_Class/White_Space/code-points');
require('unicode-9.0.0/Bidi_Class/White_Space/symbols');
require('unicode-9.0.0/Bidi_Class/White_Space/regex');

// `Script`:

require('unicode-9.0.0/Script/Adlam/code-points');
require('unicode-9.0.0/Script/Adlam/symbols');
require('unicode-9.0.0/Script/Adlam/regex');

require('unicode-9.0.0/Script/Ahom/code-points');
require('unicode-9.0.0/Script/Ahom/symbols');
require('unicode-9.0.0/Script/Ahom/regex');

require('unicode-9.0.0/Script/Anatolian_Hieroglyphs/code-points');
require('unicode-9.0.0/Script/Anatolian_Hieroglyphs/symbols');
require('unicode-9.0.0/Script/Anatolian_Hieroglyphs/regex');

require('unicode-9.0.0/Script/Arabic/code-points');
require('unicode-9.0.0/Script/Arabic/symbols');
require('unicode-9.0.0/Script/Arabic/regex');

require('unicode-9.0.0/Script/Armenian/code-points');
require('unicode-9.0.0/Script/Armenian/symbols');
require('unicode-9.0.0/Script/Armenian/regex');

require('unicode-9.0.0/Script/Avestan/code-points');
require('unicode-9.0.0/Script/Avestan/symbols');
require('unicode-9.0.0/Script/Avestan/regex');

require('unicode-9.0.0/Script/Balinese/code-points');
require('unicode-9.0.0/Script/Balinese/symbols');
require('unicode-9.0.0/Script/Balinese/regex');

require('unicode-9.0.0/Script/Bamum/code-points');
require('unicode-9.0.0/Script/Bamum/symbols');
require('unicode-9.0.0/Script/Bamum/regex');

require('unicode-9.0.0/Script/Bassa_Vah/code-points');
require('unicode-9.0.0/Script/Bassa_Vah/symbols');
require('unicode-9.0.0/Script/Bassa_Vah/regex');

require('unicode-9.0.0/Script/Batak/code-points');
require('unicode-9.0.0/Script/Batak/symbols');
require('unicode-9.0.0/Script/Batak/regex');

require('unicode-9.0.0/Script/Bengali/code-points');
require('unicode-9.0.0/Script/Bengali/symbols');
require('unicode-9.0.0/Script/Bengali/regex');

require('unicode-9.0.0/Script/Bhaiksuki/code-points');
require('unicode-9.0.0/Script/Bhaiksuki/symbols');
require('unicode-9.0.0/Script/Bhaiksuki/regex');

require('unicode-9.0.0/Script/Bopomofo/code-points');
require('unicode-9.0.0/Script/Bopomofo/symbols');
require('unicode-9.0.0/Script/Bopomofo/regex');

require('unicode-9.0.0/Script/Brahmi/code-points');
require('unicode-9.0.0/Script/Brahmi/symbols');
require('unicode-9.0.0/Script/Brahmi/regex');

require('unicode-9.0.0/Script/Braille/code-points');
require('unicode-9.0.0/Script/Braille/symbols');
require('unicode-9.0.0/Script/Braille/regex');

require('unicode-9.0.0/Script/Buginese/code-points');
require('unicode-9.0.0/Script/Buginese/symbols');
require('unicode-9.0.0/Script/Buginese/regex');

require('unicode-9.0.0/Script/Buhid/code-points');
require('unicode-9.0.0/Script/Buhid/symbols');
require('unicode-9.0.0/Script/Buhid/regex');

require('unicode-9.0.0/Script/Canadian_Aboriginal/code-points');
require('unicode-9.0.0/Script/Canadian_Aboriginal/symbols');
require('unicode-9.0.0/Script/Canadian_Aboriginal/regex');

require('unicode-9.0.0/Script/Carian/code-points');
require('unicode-9.0.0/Script/Carian/symbols');
require('unicode-9.0.0/Script/Carian/regex');

require('unicode-9.0.0/Script/Caucasian_Albanian/code-points');
require('unicode-9.0.0/Script/Caucasian_Albanian/symbols');
require('unicode-9.0.0/Script/Caucasian_Albanian/regex');

require('unicode-9.0.0/Script/Chakma/code-points');
require('unicode-9.0.0/Script/Chakma/symbols');
require('unicode-9.0.0/Script/Chakma/regex');

require('unicode-9.0.0/Script/Cham/code-points');
require('unicode-9.0.0/Script/Cham/symbols');
require('unicode-9.0.0/Script/Cham/regex');

require('unicode-9.0.0/Script/Cherokee/code-points');
require('unicode-9.0.0/Script/Cherokee/symbols');
require('unicode-9.0.0/Script/Cherokee/regex');

require('unicode-9.0.0/Script/Common/code-points');
require('unicode-9.0.0/Script/Common/symbols');
require('unicode-9.0.0/Script/Common/regex');

require('unicode-9.0.0/Script/Coptic/code-points');
require('unicode-9.0.0/Script/Coptic/symbols');
require('unicode-9.0.0/Script/Coptic/regex');

require('unicode-9.0.0/Script/Cuneiform/code-points');
require('unicode-9.0.0/Script/Cuneiform/symbols');
require('unicode-9.0.0/Script/Cuneiform/regex');

require('unicode-9.0.0/Script/Cypriot/code-points');
require('unicode-9.0.0/Script/Cypriot/symbols');
require('unicode-9.0.0/Script/Cypriot/regex');

require('unicode-9.0.0/Script/Cyrillic/code-points');
require('unicode-9.0.0/Script/Cyrillic/symbols');
require('unicode-9.0.0/Script/Cyrillic/regex');

require('unicode-9.0.0/Script/Deseret/code-points');
require('unicode-9.0.0/Script/Deseret/symbols');
require('unicode-9.0.0/Script/Deseret/regex');

require('unicode-9.0.0/Script/Devanagari/code-points');
require('unicode-9.0.0/Script/Devanagari/symbols');
require('unicode-9.0.0/Script/Devanagari/regex');

require('unicode-9.0.0/Script/Duployan/code-points');
require('unicode-9.0.0/Script/Duployan/symbols');
require('unicode-9.0.0/Script/Duployan/regex');

require('unicode-9.0.0/Script/Egyptian_Hieroglyphs/code-points');
require('unicode-9.0.0/Script/Egyptian_Hieroglyphs/symbols');
require('unicode-9.0.0/Script/Egyptian_Hieroglyphs/regex');

require('unicode-9.0.0/Script/Elbasan/code-points');
require('unicode-9.0.0/Script/Elbasan/symbols');
require('unicode-9.0.0/Script/Elbasan/regex');

require('unicode-9.0.0/Script/Ethiopic/code-points');
require('unicode-9.0.0/Script/Ethiopic/symbols');
require('unicode-9.0.0/Script/Ethiopic/regex');

require('unicode-9.0.0/Script/Georgian/code-points');
require('unicode-9.0.0/Script/Georgian/symbols');
require('unicode-9.0.0/Script/Georgian/regex');

require('unicode-9.0.0/Script/Glagolitic/code-points');
require('unicode-9.0.0/Script/Glagolitic/symbols');
require('unicode-9.0.0/Script/Glagolitic/regex');

require('unicode-9.0.0/Script/Gothic/code-points');
require('unicode-9.0.0/Script/Gothic/symbols');
require('unicode-9.0.0/Script/Gothic/regex');

require('unicode-9.0.0/Script/Grantha/code-points');
require('unicode-9.0.0/Script/Grantha/symbols');
require('unicode-9.0.0/Script/Grantha/regex');

require('unicode-9.0.0/Script/Greek/code-points');
require('unicode-9.0.0/Script/Greek/symbols');
require('unicode-9.0.0/Script/Greek/regex');

require('unicode-9.0.0/Script/Gujarati/code-points');
require('unicode-9.0.0/Script/Gujarati/symbols');
require('unicode-9.0.0/Script/Gujarati/regex');

require('unicode-9.0.0/Script/Gurmukhi/code-points');
require('unicode-9.0.0/Script/Gurmukhi/symbols');
require('unicode-9.0.0/Script/Gurmukhi/regex');

require('unicode-9.0.0/Script/Han/code-points');
require('unicode-9.0.0/Script/Han/symbols');
require('unicode-9.0.0/Script/Han/regex');

require('unicode-9.0.0/Script/Hangul/code-points');
require('unicode-9.0.0/Script/Hangul/symbols');
require('unicode-9.0.0/Script/Hangul/regex');

require('unicode-9.0.0/Script/Hanunoo/code-points');
require('unicode-9.0.0/Script/Hanunoo/symbols');
require('unicode-9.0.0/Script/Hanunoo/regex');

require('unicode-9.0.0/Script/Hatran/code-points');
require('unicode-9.0.0/Script/Hatran/symbols');
require('unicode-9.0.0/Script/Hatran/regex');

require('unicode-9.0.0/Script/Hebrew/code-points');
require('unicode-9.0.0/Script/Hebrew/symbols');
require('unicode-9.0.0/Script/Hebrew/regex');

require('unicode-9.0.0/Script/Hiragana/code-points');
require('unicode-9.0.0/Script/Hiragana/symbols');
require('unicode-9.0.0/Script/Hiragana/regex');

require('unicode-9.0.0/Script/Imperial_Aramaic/code-points');
require('unicode-9.0.0/Script/Imperial_Aramaic/symbols');
require('unicode-9.0.0/Script/Imperial_Aramaic/regex');

require('unicode-9.0.0/Script/Inherited/code-points');
require('unicode-9.0.0/Script/Inherited/symbols');
require('unicode-9.0.0/Script/Inherited/regex');

require('unicode-9.0.0/Script/Inscriptional_Pahlavi/code-points');
require('unicode-9.0.0/Script/Inscriptional_Pahlavi/symbols');
require('unicode-9.0.0/Script/Inscriptional_Pahlavi/regex');

require('unicode-9.0.0/Script/Inscriptional_Parthian/code-points');
require('unicode-9.0.0/Script/Inscriptional_Parthian/symbols');
require('unicode-9.0.0/Script/Inscriptional_Parthian/regex');

require('unicode-9.0.0/Script/Javanese/code-points');
require('unicode-9.0.0/Script/Javanese/symbols');
require('unicode-9.0.0/Script/Javanese/regex');

require('unicode-9.0.0/Script/Kaithi/code-points');
require('unicode-9.0.0/Script/Kaithi/symbols');
require('unicode-9.0.0/Script/Kaithi/regex');

require('unicode-9.0.0/Script/Kannada/code-points');
require('unicode-9.0.0/Script/Kannada/symbols');
require('unicode-9.0.0/Script/Kannada/regex');

require('unicode-9.0.0/Script/Katakana/code-points');
require('unicode-9.0.0/Script/Katakana/symbols');
require('unicode-9.0.0/Script/Katakana/regex');

require('unicode-9.0.0/Script/Kayah_Li/code-points');
require('unicode-9.0.0/Script/Kayah_Li/symbols');
require('unicode-9.0.0/Script/Kayah_Li/regex');

require('unicode-9.0.0/Script/Kharoshthi/code-points');
require('unicode-9.0.0/Script/Kharoshthi/symbols');
require('unicode-9.0.0/Script/Kharoshthi/regex');

require('unicode-9.0.0/Script/Khmer/code-points');
require('unicode-9.0.0/Script/Khmer/symbols');
require('unicode-9.0.0/Script/Khmer/regex');

require('unicode-9.0.0/Script/Khojki/code-points');
require('unicode-9.0.0/Script/Khojki/symbols');
require('unicode-9.0.0/Script/Khojki/regex');

require('unicode-9.0.0/Script/Khudawadi/code-points');
require('unicode-9.0.0/Script/Khudawadi/symbols');
require('unicode-9.0.0/Script/Khudawadi/regex');

require('unicode-9.0.0/Script/Lao/code-points');
require('unicode-9.0.0/Script/Lao/symbols');
require('unicode-9.0.0/Script/Lao/regex');

require('unicode-9.0.0/Script/Latin/code-points');
require('unicode-9.0.0/Script/Latin/symbols');
require('unicode-9.0.0/Script/Latin/regex');

require('unicode-9.0.0/Script/Lepcha/code-points');
require('unicode-9.0.0/Script/Lepcha/symbols');
require('unicode-9.0.0/Script/Lepcha/regex');

require('unicode-9.0.0/Script/Limbu/code-points');
require('unicode-9.0.0/Script/Limbu/symbols');
require('unicode-9.0.0/Script/Limbu/regex');

require('unicode-9.0.0/Script/Linear_A/code-points');
require('unicode-9.0.0/Script/Linear_A/symbols');
require('unicode-9.0.0/Script/Linear_A/regex');

require('unicode-9.0.0/Script/Linear_B/code-points');
require('unicode-9.0.0/Script/Linear_B/symbols');
require('unicode-9.0.0/Script/Linear_B/regex');

require('unicode-9.0.0/Script/Lisu/code-points');
require('unicode-9.0.0/Script/Lisu/symbols');
require('unicode-9.0.0/Script/Lisu/regex');

require('unicode-9.0.0/Script/Lycian/code-points');
require('unicode-9.0.0/Script/Lycian/symbols');
require('unicode-9.0.0/Script/Lycian/regex');

require('unicode-9.0.0/Script/Lydian/code-points');
require('unicode-9.0.0/Script/Lydian/symbols');
require('unicode-9.0.0/Script/Lydian/regex');

require('unicode-9.0.0/Script/Mahajani/code-points');
require('unicode-9.0.0/Script/Mahajani/symbols');
require('unicode-9.0.0/Script/Mahajani/regex');

require('unicode-9.0.0/Script/Malayalam/code-points');
require('unicode-9.0.0/Script/Malayalam/symbols');
require('unicode-9.0.0/Script/Malayalam/regex');

require('unicode-9.0.0/Script/Mandaic/code-points');
require('unicode-9.0.0/Script/Mandaic/symbols');
require('unicode-9.0.0/Script/Mandaic/regex');

require('unicode-9.0.0/Script/Manichaean/code-points');
require('unicode-9.0.0/Script/Manichaean/symbols');
require('unicode-9.0.0/Script/Manichaean/regex');

require('unicode-9.0.0/Script/Marchen/code-points');
require('unicode-9.0.0/Script/Marchen/symbols');
require('unicode-9.0.0/Script/Marchen/regex');

require('unicode-9.0.0/Script/Meetei_Mayek/code-points');
require('unicode-9.0.0/Script/Meetei_Mayek/symbols');
require('unicode-9.0.0/Script/Meetei_Mayek/regex');

require('unicode-9.0.0/Script/Mende_Kikakui/code-points');
require('unicode-9.0.0/Script/Mende_Kikakui/symbols');
require('unicode-9.0.0/Script/Mende_Kikakui/regex');

require('unicode-9.0.0/Script/Meroitic_Cursive/code-points');
require('unicode-9.0.0/Script/Meroitic_Cursive/symbols');
require('unicode-9.0.0/Script/Meroitic_Cursive/regex');

require('unicode-9.0.0/Script/Meroitic_Hieroglyphs/code-points');
require('unicode-9.0.0/Script/Meroitic_Hieroglyphs/symbols');
require('unicode-9.0.0/Script/Meroitic_Hieroglyphs/regex');

require('unicode-9.0.0/Script/Miao/code-points');
require('unicode-9.0.0/Script/Miao/symbols');
require('unicode-9.0.0/Script/Miao/regex');

require('unicode-9.0.0/Script/Modi/code-points');
require('unicode-9.0.0/Script/Modi/symbols');
require('unicode-9.0.0/Script/Modi/regex');

require('unicode-9.0.0/Script/Mongolian/code-points');
require('unicode-9.0.0/Script/Mongolian/symbols');
require('unicode-9.0.0/Script/Mongolian/regex');

require('unicode-9.0.0/Script/Mro/code-points');
require('unicode-9.0.0/Script/Mro/symbols');
require('unicode-9.0.0/Script/Mro/regex');

require('unicode-9.0.0/Script/Multani/code-points');
require('unicode-9.0.0/Script/Multani/symbols');
require('unicode-9.0.0/Script/Multani/regex');

require('unicode-9.0.0/Script/Myanmar/code-points');
require('unicode-9.0.0/Script/Myanmar/symbols');
require('unicode-9.0.0/Script/Myanmar/regex');

require('unicode-9.0.0/Script/Nabataean/code-points');
require('unicode-9.0.0/Script/Nabataean/symbols');
require('unicode-9.0.0/Script/Nabataean/regex');

require('unicode-9.0.0/Script/New_Tai_Lue/code-points');
require('unicode-9.0.0/Script/New_Tai_Lue/symbols');
require('unicode-9.0.0/Script/New_Tai_Lue/regex');

require('unicode-9.0.0/Script/Newa/code-points');
require('unicode-9.0.0/Script/Newa/symbols');
require('unicode-9.0.0/Script/Newa/regex');

require('unicode-9.0.0/Script/Nko/code-points');
require('unicode-9.0.0/Script/Nko/symbols');
require('unicode-9.0.0/Script/Nko/regex');

require('unicode-9.0.0/Script/Ogham/code-points');
require('unicode-9.0.0/Script/Ogham/symbols');
require('unicode-9.0.0/Script/Ogham/regex');

require('unicode-9.0.0/Script/Ol_Chiki/code-points');
require('unicode-9.0.0/Script/Ol_Chiki/symbols');
require('unicode-9.0.0/Script/Ol_Chiki/regex');

require('unicode-9.0.0/Script/Old_Hungarian/code-points');
require('unicode-9.0.0/Script/Old_Hungarian/symbols');
require('unicode-9.0.0/Script/Old_Hungarian/regex');

require('unicode-9.0.0/Script/Old_Italic/code-points');
require('unicode-9.0.0/Script/Old_Italic/symbols');
require('unicode-9.0.0/Script/Old_Italic/regex');

require('unicode-9.0.0/Script/Old_North_Arabian/code-points');
require('unicode-9.0.0/Script/Old_North_Arabian/symbols');
require('unicode-9.0.0/Script/Old_North_Arabian/regex');

require('unicode-9.0.0/Script/Old_Permic/code-points');
require('unicode-9.0.0/Script/Old_Permic/symbols');
require('unicode-9.0.0/Script/Old_Permic/regex');

require('unicode-9.0.0/Script/Old_Persian/code-points');
require('unicode-9.0.0/Script/Old_Persian/symbols');
require('unicode-9.0.0/Script/Old_Persian/regex');

require('unicode-9.0.0/Script/Old_South_Arabian/code-points');
require('unicode-9.0.0/Script/Old_South_Arabian/symbols');
require('unicode-9.0.0/Script/Old_South_Arabian/regex');

require('unicode-9.0.0/Script/Old_Turkic/code-points');
require('unicode-9.0.0/Script/Old_Turkic/symbols');
require('unicode-9.0.0/Script/Old_Turkic/regex');

require('unicode-9.0.0/Script/Oriya/code-points');
require('unicode-9.0.0/Script/Oriya/symbols');
require('unicode-9.0.0/Script/Oriya/regex');

require('unicode-9.0.0/Script/Osage/code-points');
require('unicode-9.0.0/Script/Osage/symbols');
require('unicode-9.0.0/Script/Osage/regex');

require('unicode-9.0.0/Script/Osmanya/code-points');
require('unicode-9.0.0/Script/Osmanya/symbols');
require('unicode-9.0.0/Script/Osmanya/regex');

require('unicode-9.0.0/Script/Pahawh_Hmong/code-points');
require('unicode-9.0.0/Script/Pahawh_Hmong/symbols');
require('unicode-9.0.0/Script/Pahawh_Hmong/regex');

require('unicode-9.0.0/Script/Palmyrene/code-points');
require('unicode-9.0.0/Script/Palmyrene/symbols');
require('unicode-9.0.0/Script/Palmyrene/regex');

require('unicode-9.0.0/Script/Pau_Cin_Hau/code-points');
require('unicode-9.0.0/Script/Pau_Cin_Hau/symbols');
require('unicode-9.0.0/Script/Pau_Cin_Hau/regex');

require('unicode-9.0.0/Script/Phags_Pa/code-points');
require('unicode-9.0.0/Script/Phags_Pa/symbols');
require('unicode-9.0.0/Script/Phags_Pa/regex');

require('unicode-9.0.0/Script/Phoenician/code-points');
require('unicode-9.0.0/Script/Phoenician/symbols');
require('unicode-9.0.0/Script/Phoenician/regex');

require('unicode-9.0.0/Script/Psalter_Pahlavi/code-points');
require('unicode-9.0.0/Script/Psalter_Pahlavi/symbols');
require('unicode-9.0.0/Script/Psalter_Pahlavi/regex');

require('unicode-9.0.0/Script/Rejang/code-points');
require('unicode-9.0.0/Script/Rejang/symbols');
require('unicode-9.0.0/Script/Rejang/regex');

require('unicode-9.0.0/Script/Runic/code-points');
require('unicode-9.0.0/Script/Runic/symbols');
require('unicode-9.0.0/Script/Runic/regex');

require('unicode-9.0.0/Script/Samaritan/code-points');
require('unicode-9.0.0/Script/Samaritan/symbols');
require('unicode-9.0.0/Script/Samaritan/regex');

require('unicode-9.0.0/Script/Saurashtra/code-points');
require('unicode-9.0.0/Script/Saurashtra/symbols');
require('unicode-9.0.0/Script/Saurashtra/regex');

require('unicode-9.0.0/Script/Sharada/code-points');
require('unicode-9.0.0/Script/Sharada/symbols');
require('unicode-9.0.0/Script/Sharada/regex');

require('unicode-9.0.0/Script/Shavian/code-points');
require('unicode-9.0.0/Script/Shavian/symbols');
require('unicode-9.0.0/Script/Shavian/regex');

require('unicode-9.0.0/Script/Siddham/code-points');
require('unicode-9.0.0/Script/Siddham/symbols');
require('unicode-9.0.0/Script/Siddham/regex');

require('unicode-9.0.0/Script/SignWriting/code-points');
require('unicode-9.0.0/Script/SignWriting/symbols');
require('unicode-9.0.0/Script/SignWriting/regex');

require('unicode-9.0.0/Script/Sinhala/code-points');
require('unicode-9.0.0/Script/Sinhala/symbols');
require('unicode-9.0.0/Script/Sinhala/regex');

require('unicode-9.0.0/Script/Sora_Sompeng/code-points');
require('unicode-9.0.0/Script/Sora_Sompeng/symbols');
require('unicode-9.0.0/Script/Sora_Sompeng/regex');

require('unicode-9.0.0/Script/Sundanese/code-points');
require('unicode-9.0.0/Script/Sundanese/symbols');
require('unicode-9.0.0/Script/Sundanese/regex');

require('unicode-9.0.0/Script/Syloti_Nagri/code-points');
require('unicode-9.0.0/Script/Syloti_Nagri/symbols');
require('unicode-9.0.0/Script/Syloti_Nagri/regex');

require('unicode-9.0.0/Script/Syriac/code-points');
require('unicode-9.0.0/Script/Syriac/symbols');
require('unicode-9.0.0/Script/Syriac/regex');

require('unicode-9.0.0/Script/Tagalog/code-points');
require('unicode-9.0.0/Script/Tagalog/symbols');
require('unicode-9.0.0/Script/Tagalog/regex');

require('unicode-9.0.0/Script/Tagbanwa/code-points');
require('unicode-9.0.0/Script/Tagbanwa/symbols');
require('unicode-9.0.0/Script/Tagbanwa/regex');

require('unicode-9.0.0/Script/Tai_Le/code-points');
require('unicode-9.0.0/Script/Tai_Le/symbols');
require('unicode-9.0.0/Script/Tai_Le/regex');

require('unicode-9.0.0/Script/Tai_Tham/code-points');
require('unicode-9.0.0/Script/Tai_Tham/symbols');
require('unicode-9.0.0/Script/Tai_Tham/regex');

require('unicode-9.0.0/Script/Tai_Viet/code-points');
require('unicode-9.0.0/Script/Tai_Viet/symbols');
require('unicode-9.0.0/Script/Tai_Viet/regex');

require('unicode-9.0.0/Script/Takri/code-points');
require('unicode-9.0.0/Script/Takri/symbols');
require('unicode-9.0.0/Script/Takri/regex');

require('unicode-9.0.0/Script/Tamil/code-points');
require('unicode-9.0.0/Script/Tamil/symbols');
require('unicode-9.0.0/Script/Tamil/regex');

require('unicode-9.0.0/Script/Tangut/code-points');
require('unicode-9.0.0/Script/Tangut/symbols');
require('unicode-9.0.0/Script/Tangut/regex');

require('unicode-9.0.0/Script/Telugu/code-points');
require('unicode-9.0.0/Script/Telugu/symbols');
require('unicode-9.0.0/Script/Telugu/regex');

require('unicode-9.0.0/Script/Thaana/code-points');
require('unicode-9.0.0/Script/Thaana/symbols');
require('unicode-9.0.0/Script/Thaana/regex');

require('unicode-9.0.0/Script/Thai/code-points');
require('unicode-9.0.0/Script/Thai/symbols');
require('unicode-9.0.0/Script/Thai/regex');

require('unicode-9.0.0/Script/Tibetan/code-points');
require('unicode-9.0.0/Script/Tibetan/symbols');
require('unicode-9.0.0/Script/Tibetan/regex');

require('unicode-9.0.0/Script/Tifinagh/code-points');
require('unicode-9.0.0/Script/Tifinagh/symbols');
require('unicode-9.0.0/Script/Tifinagh/regex');

require('unicode-9.0.0/Script/Tirhuta/code-points');
require('unicode-9.0.0/Script/Tirhuta/symbols');
require('unicode-9.0.0/Script/Tirhuta/regex');

require('unicode-9.0.0/Script/Ugaritic/code-points');
require('unicode-9.0.0/Script/Ugaritic/symbols');
require('unicode-9.0.0/Script/Ugaritic/regex');

require('unicode-9.0.0/Script/Vai/code-points');
require('unicode-9.0.0/Script/Vai/symbols');
require('unicode-9.0.0/Script/Vai/regex');

require('unicode-9.0.0/Script/Warang_Citi/code-points');
require('unicode-9.0.0/Script/Warang_Citi/symbols');
require('unicode-9.0.0/Script/Warang_Citi/regex');

require('unicode-9.0.0/Script/Yi/code-points');
require('unicode-9.0.0/Script/Yi/symbols');
require('unicode-9.0.0/Script/Yi/regex');

// `Script_Extensions`:

require('unicode-9.0.0/Script_Extensions/Adlam/code-points');
require('unicode-9.0.0/Script_Extensions/Adlam/symbols');
require('unicode-9.0.0/Script_Extensions/Adlam/regex');

require('unicode-9.0.0/Script_Extensions/Ahom/code-points');
require('unicode-9.0.0/Script_Extensions/Ahom/symbols');
require('unicode-9.0.0/Script_Extensions/Ahom/regex');

require('unicode-9.0.0/Script_Extensions/Anatolian_Hieroglyphs/code-points');
require('unicode-9.0.0/Script_Extensions/Anatolian_Hieroglyphs/symbols');
require('unicode-9.0.0/Script_Extensions/Anatolian_Hieroglyphs/regex');

require('unicode-9.0.0/Script_Extensions/Arabic/code-points');
require('unicode-9.0.0/Script_Extensions/Arabic/symbols');
require('unicode-9.0.0/Script_Extensions/Arabic/regex');

require('unicode-9.0.0/Script_Extensions/Armenian/code-points');
require('unicode-9.0.0/Script_Extensions/Armenian/symbols');
require('unicode-9.0.0/Script_Extensions/Armenian/regex');

require('unicode-9.0.0/Script_Extensions/Avestan/code-points');
require('unicode-9.0.0/Script_Extensions/Avestan/symbols');
require('unicode-9.0.0/Script_Extensions/Avestan/regex');

require('unicode-9.0.0/Script_Extensions/Balinese/code-points');
require('unicode-9.0.0/Script_Extensions/Balinese/symbols');
require('unicode-9.0.0/Script_Extensions/Balinese/regex');

require('unicode-9.0.0/Script_Extensions/Bamum/code-points');
require('unicode-9.0.0/Script_Extensions/Bamum/symbols');
require('unicode-9.0.0/Script_Extensions/Bamum/regex');

require('unicode-9.0.0/Script_Extensions/Bassa_Vah/code-points');
require('unicode-9.0.0/Script_Extensions/Bassa_Vah/symbols');
require('unicode-9.0.0/Script_Extensions/Bassa_Vah/regex');

require('unicode-9.0.0/Script_Extensions/Batak/code-points');
require('unicode-9.0.0/Script_Extensions/Batak/symbols');
require('unicode-9.0.0/Script_Extensions/Batak/regex');

require('unicode-9.0.0/Script_Extensions/Bengali/code-points');
require('unicode-9.0.0/Script_Extensions/Bengali/symbols');
require('unicode-9.0.0/Script_Extensions/Bengali/regex');

require('unicode-9.0.0/Script_Extensions/Bhaiksuki/code-points');
require('unicode-9.0.0/Script_Extensions/Bhaiksuki/symbols');
require('unicode-9.0.0/Script_Extensions/Bhaiksuki/regex');

require('unicode-9.0.0/Script_Extensions/Bopomofo/code-points');
require('unicode-9.0.0/Script_Extensions/Bopomofo/symbols');
require('unicode-9.0.0/Script_Extensions/Bopomofo/regex');

require('unicode-9.0.0/Script_Extensions/Brahmi/code-points');
require('unicode-9.0.0/Script_Extensions/Brahmi/symbols');
require('unicode-9.0.0/Script_Extensions/Brahmi/regex');

require('unicode-9.0.0/Script_Extensions/Braille/code-points');
require('unicode-9.0.0/Script_Extensions/Braille/symbols');
require('unicode-9.0.0/Script_Extensions/Braille/regex');

require('unicode-9.0.0/Script_Extensions/Buginese/code-points');
require('unicode-9.0.0/Script_Extensions/Buginese/symbols');
require('unicode-9.0.0/Script_Extensions/Buginese/regex');

require('unicode-9.0.0/Script_Extensions/Buhid/code-points');
require('unicode-9.0.0/Script_Extensions/Buhid/symbols');
require('unicode-9.0.0/Script_Extensions/Buhid/regex');

require('unicode-9.0.0/Script_Extensions/Canadian_Aboriginal/code-points');
require('unicode-9.0.0/Script_Extensions/Canadian_Aboriginal/symbols');
require('unicode-9.0.0/Script_Extensions/Canadian_Aboriginal/regex');

require('unicode-9.0.0/Script_Extensions/Carian/code-points');
require('unicode-9.0.0/Script_Extensions/Carian/symbols');
require('unicode-9.0.0/Script_Extensions/Carian/regex');

require('unicode-9.0.0/Script_Extensions/Caucasian_Albanian/code-points');
require('unicode-9.0.0/Script_Extensions/Caucasian_Albanian/symbols');
require('unicode-9.0.0/Script_Extensions/Caucasian_Albanian/regex');

require('unicode-9.0.0/Script_Extensions/Chakma/code-points');
require('unicode-9.0.0/Script_Extensions/Chakma/symbols');
require('unicode-9.0.0/Script_Extensions/Chakma/regex');

require('unicode-9.0.0/Script_Extensions/Cham/code-points');
require('unicode-9.0.0/Script_Extensions/Cham/symbols');
require('unicode-9.0.0/Script_Extensions/Cham/regex');

require('unicode-9.0.0/Script_Extensions/Cherokee/code-points');
require('unicode-9.0.0/Script_Extensions/Cherokee/symbols');
require('unicode-9.0.0/Script_Extensions/Cherokee/regex');

require('unicode-9.0.0/Script_Extensions/Common/code-points');
require('unicode-9.0.0/Script_Extensions/Common/symbols');
require('unicode-9.0.0/Script_Extensions/Common/regex');

require('unicode-9.0.0/Script_Extensions/Coptic/code-points');
require('unicode-9.0.0/Script_Extensions/Coptic/symbols');
require('unicode-9.0.0/Script_Extensions/Coptic/regex');

require('unicode-9.0.0/Script_Extensions/Cuneiform/code-points');
require('unicode-9.0.0/Script_Extensions/Cuneiform/symbols');
require('unicode-9.0.0/Script_Extensions/Cuneiform/regex');

require('unicode-9.0.0/Script_Extensions/Cypriot/code-points');
require('unicode-9.0.0/Script_Extensions/Cypriot/symbols');
require('unicode-9.0.0/Script_Extensions/Cypriot/regex');

require('unicode-9.0.0/Script_Extensions/Cyrillic/code-points');
require('unicode-9.0.0/Script_Extensions/Cyrillic/symbols');
require('unicode-9.0.0/Script_Extensions/Cyrillic/regex');

require('unicode-9.0.0/Script_Extensions/Deseret/code-points');
require('unicode-9.0.0/Script_Extensions/Deseret/symbols');
require('unicode-9.0.0/Script_Extensions/Deseret/regex');

require('unicode-9.0.0/Script_Extensions/Devanagari/code-points');
require('unicode-9.0.0/Script_Extensions/Devanagari/symbols');
require('unicode-9.0.0/Script_Extensions/Devanagari/regex');

require('unicode-9.0.0/Script_Extensions/Duployan/code-points');
require('unicode-9.0.0/Script_Extensions/Duployan/symbols');
require('unicode-9.0.0/Script_Extensions/Duployan/regex');

require('unicode-9.0.0/Script_Extensions/Egyptian_Hieroglyphs/code-points');
require('unicode-9.0.0/Script_Extensions/Egyptian_Hieroglyphs/symbols');
require('unicode-9.0.0/Script_Extensions/Egyptian_Hieroglyphs/regex');

require('unicode-9.0.0/Script_Extensions/Elbasan/code-points');
require('unicode-9.0.0/Script_Extensions/Elbasan/symbols');
require('unicode-9.0.0/Script_Extensions/Elbasan/regex');

require('unicode-9.0.0/Script_Extensions/Ethiopic/code-points');
require('unicode-9.0.0/Script_Extensions/Ethiopic/symbols');
require('unicode-9.0.0/Script_Extensions/Ethiopic/regex');

require('unicode-9.0.0/Script_Extensions/Georgian/code-points');
require('unicode-9.0.0/Script_Extensions/Georgian/symbols');
require('unicode-9.0.0/Script_Extensions/Georgian/regex');

require('unicode-9.0.0/Script_Extensions/Glagolitic/code-points');
require('unicode-9.0.0/Script_Extensions/Glagolitic/symbols');
require('unicode-9.0.0/Script_Extensions/Glagolitic/regex');

require('unicode-9.0.0/Script_Extensions/Gothic/code-points');
require('unicode-9.0.0/Script_Extensions/Gothic/symbols');
require('unicode-9.0.0/Script_Extensions/Gothic/regex');

require('unicode-9.0.0/Script_Extensions/Grantha/code-points');
require('unicode-9.0.0/Script_Extensions/Grantha/symbols');
require('unicode-9.0.0/Script_Extensions/Grantha/regex');

require('unicode-9.0.0/Script_Extensions/Greek/code-points');
require('unicode-9.0.0/Script_Extensions/Greek/symbols');
require('unicode-9.0.0/Script_Extensions/Greek/regex');

require('unicode-9.0.0/Script_Extensions/Gujarati/code-points');
require('unicode-9.0.0/Script_Extensions/Gujarati/symbols');
require('unicode-9.0.0/Script_Extensions/Gujarati/regex');

require('unicode-9.0.0/Script_Extensions/Gurmukhi/code-points');
require('unicode-9.0.0/Script_Extensions/Gurmukhi/symbols');
require('unicode-9.0.0/Script_Extensions/Gurmukhi/regex');

require('unicode-9.0.0/Script_Extensions/Han/code-points');
require('unicode-9.0.0/Script_Extensions/Han/symbols');
require('unicode-9.0.0/Script_Extensions/Han/regex');

require('unicode-9.0.0/Script_Extensions/Hangul/code-points');
require('unicode-9.0.0/Script_Extensions/Hangul/symbols');
require('unicode-9.0.0/Script_Extensions/Hangul/regex');

require('unicode-9.0.0/Script_Extensions/Hanunoo/code-points');
require('unicode-9.0.0/Script_Extensions/Hanunoo/symbols');
require('unicode-9.0.0/Script_Extensions/Hanunoo/regex');

require('unicode-9.0.0/Script_Extensions/Hatran/code-points');
require('unicode-9.0.0/Script_Extensions/Hatran/symbols');
require('unicode-9.0.0/Script_Extensions/Hatran/regex');

require('unicode-9.0.0/Script_Extensions/Hebrew/code-points');
require('unicode-9.0.0/Script_Extensions/Hebrew/symbols');
require('unicode-9.0.0/Script_Extensions/Hebrew/regex');

require('unicode-9.0.0/Script_Extensions/Hiragana/code-points');
require('unicode-9.0.0/Script_Extensions/Hiragana/symbols');
require('unicode-9.0.0/Script_Extensions/Hiragana/regex');

require('unicode-9.0.0/Script_Extensions/Imperial_Aramaic/code-points');
require('unicode-9.0.0/Script_Extensions/Imperial_Aramaic/symbols');
require('unicode-9.0.0/Script_Extensions/Imperial_Aramaic/regex');

require('unicode-9.0.0/Script_Extensions/Inherited/code-points');
require('unicode-9.0.0/Script_Extensions/Inherited/symbols');
require('unicode-9.0.0/Script_Extensions/Inherited/regex');

require('unicode-9.0.0/Script_Extensions/Inscriptional_Pahlavi/code-points');
require('unicode-9.0.0/Script_Extensions/Inscriptional_Pahlavi/symbols');
require('unicode-9.0.0/Script_Extensions/Inscriptional_Pahlavi/regex');

require('unicode-9.0.0/Script_Extensions/Inscriptional_Parthian/code-points');
require('unicode-9.0.0/Script_Extensions/Inscriptional_Parthian/symbols');
require('unicode-9.0.0/Script_Extensions/Inscriptional_Parthian/regex');

require('unicode-9.0.0/Script_Extensions/Javanese/code-points');
require('unicode-9.0.0/Script_Extensions/Javanese/symbols');
require('unicode-9.0.0/Script_Extensions/Javanese/regex');

require('unicode-9.0.0/Script_Extensions/Kaithi/code-points');
require('unicode-9.0.0/Script_Extensions/Kaithi/symbols');
require('unicode-9.0.0/Script_Extensions/Kaithi/regex');

require('unicode-9.0.0/Script_Extensions/Kannada/code-points');
require('unicode-9.0.0/Script_Extensions/Kannada/symbols');
require('unicode-9.0.0/Script_Extensions/Kannada/regex');

require('unicode-9.0.0/Script_Extensions/Katakana/code-points');
require('unicode-9.0.0/Script_Extensions/Katakana/symbols');
require('unicode-9.0.0/Script_Extensions/Katakana/regex');

require('unicode-9.0.0/Script_Extensions/Kayah_Li/code-points');
require('unicode-9.0.0/Script_Extensions/Kayah_Li/symbols');
require('unicode-9.0.0/Script_Extensions/Kayah_Li/regex');

require('unicode-9.0.0/Script_Extensions/Kharoshthi/code-points');
require('unicode-9.0.0/Script_Extensions/Kharoshthi/symbols');
require('unicode-9.0.0/Script_Extensions/Kharoshthi/regex');

require('unicode-9.0.0/Script_Extensions/Khmer/code-points');
require('unicode-9.0.0/Script_Extensions/Khmer/symbols');
require('unicode-9.0.0/Script_Extensions/Khmer/regex');

require('unicode-9.0.0/Script_Extensions/Khojki/code-points');
require('unicode-9.0.0/Script_Extensions/Khojki/symbols');
require('unicode-9.0.0/Script_Extensions/Khojki/regex');

require('unicode-9.0.0/Script_Extensions/Khudawadi/code-points');
require('unicode-9.0.0/Script_Extensions/Khudawadi/symbols');
require('unicode-9.0.0/Script_Extensions/Khudawadi/regex');

require('unicode-9.0.0/Script_Extensions/Lao/code-points');
require('unicode-9.0.0/Script_Extensions/Lao/symbols');
require('unicode-9.0.0/Script_Extensions/Lao/regex');

require('unicode-9.0.0/Script_Extensions/Latin/code-points');
require('unicode-9.0.0/Script_Extensions/Latin/symbols');
require('unicode-9.0.0/Script_Extensions/Latin/regex');

require('unicode-9.0.0/Script_Extensions/Lepcha/code-points');
require('unicode-9.0.0/Script_Extensions/Lepcha/symbols');
require('unicode-9.0.0/Script_Extensions/Lepcha/regex');

require('unicode-9.0.0/Script_Extensions/Limbu/code-points');
require('unicode-9.0.0/Script_Extensions/Limbu/symbols');
require('unicode-9.0.0/Script_Extensions/Limbu/regex');

require('unicode-9.0.0/Script_Extensions/Linear_A/code-points');
require('unicode-9.0.0/Script_Extensions/Linear_A/symbols');
require('unicode-9.0.0/Script_Extensions/Linear_A/regex');

require('unicode-9.0.0/Script_Extensions/Linear_B/code-points');
require('unicode-9.0.0/Script_Extensions/Linear_B/symbols');
require('unicode-9.0.0/Script_Extensions/Linear_B/regex');

require('unicode-9.0.0/Script_Extensions/Lisu/code-points');
require('unicode-9.0.0/Script_Extensions/Lisu/symbols');
require('unicode-9.0.0/Script_Extensions/Lisu/regex');

require('unicode-9.0.0/Script_Extensions/Lycian/code-points');
require('unicode-9.0.0/Script_Extensions/Lycian/symbols');
require('unicode-9.0.0/Script_Extensions/Lycian/regex');

require('unicode-9.0.0/Script_Extensions/Lydian/code-points');
require('unicode-9.0.0/Script_Extensions/Lydian/symbols');
require('unicode-9.0.0/Script_Extensions/Lydian/regex');

require('unicode-9.0.0/Script_Extensions/Mahajani/code-points');
require('unicode-9.0.0/Script_Extensions/Mahajani/symbols');
require('unicode-9.0.0/Script_Extensions/Mahajani/regex');

require('unicode-9.0.0/Script_Extensions/Malayalam/code-points');
require('unicode-9.0.0/Script_Extensions/Malayalam/symbols');
require('unicode-9.0.0/Script_Extensions/Malayalam/regex');

require('unicode-9.0.0/Script_Extensions/Mandaic/code-points');
require('unicode-9.0.0/Script_Extensions/Mandaic/symbols');
require('unicode-9.0.0/Script_Extensions/Mandaic/regex');

require('unicode-9.0.0/Script_Extensions/Manichaean/code-points');
require('unicode-9.0.0/Script_Extensions/Manichaean/symbols');
require('unicode-9.0.0/Script_Extensions/Manichaean/regex');

require('unicode-9.0.0/Script_Extensions/Marchen/code-points');
require('unicode-9.0.0/Script_Extensions/Marchen/symbols');
require('unicode-9.0.0/Script_Extensions/Marchen/regex');

require('unicode-9.0.0/Script_Extensions/Meetei_Mayek/code-points');
require('unicode-9.0.0/Script_Extensions/Meetei_Mayek/symbols');
require('unicode-9.0.0/Script_Extensions/Meetei_Mayek/regex');

require('unicode-9.0.0/Script_Extensions/Mende_Kikakui/code-points');
require('unicode-9.0.0/Script_Extensions/Mende_Kikakui/symbols');
require('unicode-9.0.0/Script_Extensions/Mende_Kikakui/regex');

require('unicode-9.0.0/Script_Extensions/Meroitic_Cursive/code-points');
require('unicode-9.0.0/Script_Extensions/Meroitic_Cursive/symbols');
require('unicode-9.0.0/Script_Extensions/Meroitic_Cursive/regex');

require('unicode-9.0.0/Script_Extensions/Meroitic_Hieroglyphs/code-points');
require('unicode-9.0.0/Script_Extensions/Meroitic_Hieroglyphs/symbols');
require('unicode-9.0.0/Script_Extensions/Meroitic_Hieroglyphs/regex');

require('unicode-9.0.0/Script_Extensions/Miao/code-points');
require('unicode-9.0.0/Script_Extensions/Miao/symbols');
require('unicode-9.0.0/Script_Extensions/Miao/regex');

require('unicode-9.0.0/Script_Extensions/Modi/code-points');
require('unicode-9.0.0/Script_Extensions/Modi/symbols');
require('unicode-9.0.0/Script_Extensions/Modi/regex');

require('unicode-9.0.0/Script_Extensions/Mongolian/code-points');
require('unicode-9.0.0/Script_Extensions/Mongolian/symbols');
require('unicode-9.0.0/Script_Extensions/Mongolian/regex');

require('unicode-9.0.0/Script_Extensions/Mro/code-points');
require('unicode-9.0.0/Script_Extensions/Mro/symbols');
require('unicode-9.0.0/Script_Extensions/Mro/regex');

require('unicode-9.0.0/Script_Extensions/Multani/code-points');
require('unicode-9.0.0/Script_Extensions/Multani/symbols');
require('unicode-9.0.0/Script_Extensions/Multani/regex');

require('unicode-9.0.0/Script_Extensions/Myanmar/code-points');
require('unicode-9.0.0/Script_Extensions/Myanmar/symbols');
require('unicode-9.0.0/Script_Extensions/Myanmar/regex');

require('unicode-9.0.0/Script_Extensions/Nabataean/code-points');
require('unicode-9.0.0/Script_Extensions/Nabataean/symbols');
require('unicode-9.0.0/Script_Extensions/Nabataean/regex');

require('unicode-9.0.0/Script_Extensions/New_Tai_Lue/code-points');
require('unicode-9.0.0/Script_Extensions/New_Tai_Lue/symbols');
require('unicode-9.0.0/Script_Extensions/New_Tai_Lue/regex');

require('unicode-9.0.0/Script_Extensions/Newa/code-points');
require('unicode-9.0.0/Script_Extensions/Newa/symbols');
require('unicode-9.0.0/Script_Extensions/Newa/regex');

require('unicode-9.0.0/Script_Extensions/Nko/code-points');
require('unicode-9.0.0/Script_Extensions/Nko/symbols');
require('unicode-9.0.0/Script_Extensions/Nko/regex');

require('unicode-9.0.0/Script_Extensions/Ogham/code-points');
require('unicode-9.0.0/Script_Extensions/Ogham/symbols');
require('unicode-9.0.0/Script_Extensions/Ogham/regex');

require('unicode-9.0.0/Script_Extensions/Ol_Chiki/code-points');
require('unicode-9.0.0/Script_Extensions/Ol_Chiki/symbols');
require('unicode-9.0.0/Script_Extensions/Ol_Chiki/regex');

require('unicode-9.0.0/Script_Extensions/Old_Hungarian/code-points');
require('unicode-9.0.0/Script_Extensions/Old_Hungarian/symbols');
require('unicode-9.0.0/Script_Extensions/Old_Hungarian/regex');

require('unicode-9.0.0/Script_Extensions/Old_Italic/code-points');
require('unicode-9.0.0/Script_Extensions/Old_Italic/symbols');
require('unicode-9.0.0/Script_Extensions/Old_Italic/regex');

require('unicode-9.0.0/Script_Extensions/Old_North_Arabian/code-points');
require('unicode-9.0.0/Script_Extensions/Old_North_Arabian/symbols');
require('unicode-9.0.0/Script_Extensions/Old_North_Arabian/regex');

require('unicode-9.0.0/Script_Extensions/Old_Permic/code-points');
require('unicode-9.0.0/Script_Extensions/Old_Permic/symbols');
require('unicode-9.0.0/Script_Extensions/Old_Permic/regex');

require('unicode-9.0.0/Script_Extensions/Old_Persian/code-points');
require('unicode-9.0.0/Script_Extensions/Old_Persian/symbols');
require('unicode-9.0.0/Script_Extensions/Old_Persian/regex');

require('unicode-9.0.0/Script_Extensions/Old_South_Arabian/code-points');
require('unicode-9.0.0/Script_Extensions/Old_South_Arabian/symbols');
require('unicode-9.0.0/Script_Extensions/Old_South_Arabian/regex');

require('unicode-9.0.0/Script_Extensions/Old_Turkic/code-points');
require('unicode-9.0.0/Script_Extensions/Old_Turkic/symbols');
require('unicode-9.0.0/Script_Extensions/Old_Turkic/regex');

require('unicode-9.0.0/Script_Extensions/Oriya/code-points');
require('unicode-9.0.0/Script_Extensions/Oriya/symbols');
require('unicode-9.0.0/Script_Extensions/Oriya/regex');

require('unicode-9.0.0/Script_Extensions/Osage/code-points');
require('unicode-9.0.0/Script_Extensions/Osage/symbols');
require('unicode-9.0.0/Script_Extensions/Osage/regex');

require('unicode-9.0.0/Script_Extensions/Osmanya/code-points');
require('unicode-9.0.0/Script_Extensions/Osmanya/symbols');
require('unicode-9.0.0/Script_Extensions/Osmanya/regex');

require('unicode-9.0.0/Script_Extensions/Pahawh_Hmong/code-points');
require('unicode-9.0.0/Script_Extensions/Pahawh_Hmong/symbols');
require('unicode-9.0.0/Script_Extensions/Pahawh_Hmong/regex');

require('unicode-9.0.0/Script_Extensions/Palmyrene/code-points');
require('unicode-9.0.0/Script_Extensions/Palmyrene/symbols');
require('unicode-9.0.0/Script_Extensions/Palmyrene/regex');

require('unicode-9.0.0/Script_Extensions/Pau_Cin_Hau/code-points');
require('unicode-9.0.0/Script_Extensions/Pau_Cin_Hau/symbols');
require('unicode-9.0.0/Script_Extensions/Pau_Cin_Hau/regex');

require('unicode-9.0.0/Script_Extensions/Phags_Pa/code-points');
require('unicode-9.0.0/Script_Extensions/Phags_Pa/symbols');
require('unicode-9.0.0/Script_Extensions/Phags_Pa/regex');

require('unicode-9.0.0/Script_Extensions/Phoenician/code-points');
require('unicode-9.0.0/Script_Extensions/Phoenician/symbols');
require('unicode-9.0.0/Script_Extensions/Phoenician/regex');

require('unicode-9.0.0/Script_Extensions/Psalter_Pahlavi/code-points');
require('unicode-9.0.0/Script_Extensions/Psalter_Pahlavi/symbols');
require('unicode-9.0.0/Script_Extensions/Psalter_Pahlavi/regex');

require('unicode-9.0.0/Script_Extensions/Rejang/code-points');
require('unicode-9.0.0/Script_Extensions/Rejang/symbols');
require('unicode-9.0.0/Script_Extensions/Rejang/regex');

require('unicode-9.0.0/Script_Extensions/Runic/code-points');
require('unicode-9.0.0/Script_Extensions/Runic/symbols');
require('unicode-9.0.0/Script_Extensions/Runic/regex');

require('unicode-9.0.0/Script_Extensions/Samaritan/code-points');
require('unicode-9.0.0/Script_Extensions/Samaritan/symbols');
require('unicode-9.0.0/Script_Extensions/Samaritan/regex');

require('unicode-9.0.0/Script_Extensions/Saurashtra/code-points');
require('unicode-9.0.0/Script_Extensions/Saurashtra/symbols');
require('unicode-9.0.0/Script_Extensions/Saurashtra/regex');

require('unicode-9.0.0/Script_Extensions/Sharada/code-points');
require('unicode-9.0.0/Script_Extensions/Sharada/symbols');
require('unicode-9.0.0/Script_Extensions/Sharada/regex');

require('unicode-9.0.0/Script_Extensions/Shavian/code-points');
require('unicode-9.0.0/Script_Extensions/Shavian/symbols');
require('unicode-9.0.0/Script_Extensions/Shavian/regex');

require('unicode-9.0.0/Script_Extensions/Siddham/code-points');
require('unicode-9.0.0/Script_Extensions/Siddham/symbols');
require('unicode-9.0.0/Script_Extensions/Siddham/regex');

require('unicode-9.0.0/Script_Extensions/SignWriting/code-points');
require('unicode-9.0.0/Script_Extensions/SignWriting/symbols');
require('unicode-9.0.0/Script_Extensions/SignWriting/regex');

require('unicode-9.0.0/Script_Extensions/Sinhala/code-points');
require('unicode-9.0.0/Script_Extensions/Sinhala/symbols');
require('unicode-9.0.0/Script_Extensions/Sinhala/regex');

require('unicode-9.0.0/Script_Extensions/Sora_Sompeng/code-points');
require('unicode-9.0.0/Script_Extensions/Sora_Sompeng/symbols');
require('unicode-9.0.0/Script_Extensions/Sora_Sompeng/regex');

require('unicode-9.0.0/Script_Extensions/Sundanese/code-points');
require('unicode-9.0.0/Script_Extensions/Sundanese/symbols');
require('unicode-9.0.0/Script_Extensions/Sundanese/regex');

require('unicode-9.0.0/Script_Extensions/Syloti_Nagri/code-points');
require('unicode-9.0.0/Script_Extensions/Syloti_Nagri/symbols');
require('unicode-9.0.0/Script_Extensions/Syloti_Nagri/regex');

require('unicode-9.0.0/Script_Extensions/Syriac/code-points');
require('unicode-9.0.0/Script_Extensions/Syriac/symbols');
require('unicode-9.0.0/Script_Extensions/Syriac/regex');

require('unicode-9.0.0/Script_Extensions/Tagalog/code-points');
require('unicode-9.0.0/Script_Extensions/Tagalog/symbols');
require('unicode-9.0.0/Script_Extensions/Tagalog/regex');

require('unicode-9.0.0/Script_Extensions/Tagbanwa/code-points');
require('unicode-9.0.0/Script_Extensions/Tagbanwa/symbols');
require('unicode-9.0.0/Script_Extensions/Tagbanwa/regex');

require('unicode-9.0.0/Script_Extensions/Tai_Le/code-points');
require('unicode-9.0.0/Script_Extensions/Tai_Le/symbols');
require('unicode-9.0.0/Script_Extensions/Tai_Le/regex');

require('unicode-9.0.0/Script_Extensions/Tai_Tham/code-points');
require('unicode-9.0.0/Script_Extensions/Tai_Tham/symbols');
require('unicode-9.0.0/Script_Extensions/Tai_Tham/regex');

require('unicode-9.0.0/Script_Extensions/Tai_Viet/code-points');
require('unicode-9.0.0/Script_Extensions/Tai_Viet/symbols');
require('unicode-9.0.0/Script_Extensions/Tai_Viet/regex');

require('unicode-9.0.0/Script_Extensions/Takri/code-points');
require('unicode-9.0.0/Script_Extensions/Takri/symbols');
require('unicode-9.0.0/Script_Extensions/Takri/regex');

require('unicode-9.0.0/Script_Extensions/Tamil/code-points');
require('unicode-9.0.0/Script_Extensions/Tamil/symbols');
require('unicode-9.0.0/Script_Extensions/Tamil/regex');

require('unicode-9.0.0/Script_Extensions/Tangut/code-points');
require('unicode-9.0.0/Script_Extensions/Tangut/symbols');
require('unicode-9.0.0/Script_Extensions/Tangut/regex');

require('unicode-9.0.0/Script_Extensions/Telugu/code-points');
require('unicode-9.0.0/Script_Extensions/Telugu/symbols');
require('unicode-9.0.0/Script_Extensions/Telugu/regex');

require('unicode-9.0.0/Script_Extensions/Thaana/code-points');
require('unicode-9.0.0/Script_Extensions/Thaana/symbols');
require('unicode-9.0.0/Script_Extensions/Thaana/regex');

require('unicode-9.0.0/Script_Extensions/Thai/code-points');
require('unicode-9.0.0/Script_Extensions/Thai/symbols');
require('unicode-9.0.0/Script_Extensions/Thai/regex');

require('unicode-9.0.0/Script_Extensions/Tibetan/code-points');
require('unicode-9.0.0/Script_Extensions/Tibetan/symbols');
require('unicode-9.0.0/Script_Extensions/Tibetan/regex');

require('unicode-9.0.0/Script_Extensions/Tifinagh/code-points');
require('unicode-9.0.0/Script_Extensions/Tifinagh/symbols');
require('unicode-9.0.0/Script_Extensions/Tifinagh/regex');

require('unicode-9.0.0/Script_Extensions/Tirhuta/code-points');
require('unicode-9.0.0/Script_Extensions/Tirhuta/symbols');
require('unicode-9.0.0/Script_Extensions/Tirhuta/regex');

require('unicode-9.0.0/Script_Extensions/Ugaritic/code-points');
require('unicode-9.0.0/Script_Extensions/Ugaritic/symbols');
require('unicode-9.0.0/Script_Extensions/Ugaritic/regex');

require('unicode-9.0.0/Script_Extensions/Vai/code-points');
require('unicode-9.0.0/Script_Extensions/Vai/symbols');
require('unicode-9.0.0/Script_Extensions/Vai/regex');

require('unicode-9.0.0/Script_Extensions/Warang_Citi/code-points');
require('unicode-9.0.0/Script_Extensions/Warang_Citi/symbols');
require('unicode-9.0.0/Script_Extensions/Warang_Citi/regex');

require('unicode-9.0.0/Script_Extensions/Yi/code-points');
require('unicode-9.0.0/Script_Extensions/Yi/symbols');
require('unicode-9.0.0/Script_Extensions/Yi/regex');

// `Case_Folding`:

require('unicode-9.0.0/Case_Folding/C/code-points'); // lookup map from code point to code point
require('unicode-9.0.0/Case_Folding/C/code-points').get(codePoint);
require('unicode-9.0.0/Case_Folding/C/symbols'); // lookup map from symbol to symbol
require('unicode-9.0.0/Case_Folding/C/symbols').get(symbol);

require('unicode-9.0.0/Case_Folding/F/code-points'); // lookup map from code point to code point
require('unicode-9.0.0/Case_Folding/F/code-points').get(codePoint);
require('unicode-9.0.0/Case_Folding/F/symbols'); // lookup map from symbol to symbol
require('unicode-9.0.0/Case_Folding/F/symbols').get(symbol);

require('unicode-9.0.0/Case_Folding/S/code-points'); // lookup map from code point to code point
require('unicode-9.0.0/Case_Folding/S/code-points').get(codePoint);
require('unicode-9.0.0/Case_Folding/S/symbols'); // lookup map from symbol to symbol
require('unicode-9.0.0/Case_Folding/S/symbols').get(symbol);

require('unicode-9.0.0/Case_Folding/T/code-points'); // lookup map from code point to code point
require('unicode-9.0.0/Case_Folding/T/code-points').get(codePoint);
require('unicode-9.0.0/Case_Folding/T/symbols'); // lookup map from symbol to symbol
require('unicode-9.0.0/Case_Folding/T/symbols').get(symbol);

// `Block`:

require('unicode-9.0.0/Block/Adlam/code-points');
require('unicode-9.0.0/Block/Adlam/symbols');
require('unicode-9.0.0/Block/Adlam/regex');

require('unicode-9.0.0/Block/Aegean_Numbers/code-points');
require('unicode-9.0.0/Block/Aegean_Numbers/symbols');
require('unicode-9.0.0/Block/Aegean_Numbers/regex');

require('unicode-9.0.0/Block/Ahom/code-points');
require('unicode-9.0.0/Block/Ahom/symbols');
require('unicode-9.0.0/Block/Ahom/regex');

require('unicode-9.0.0/Block/Alchemical_Symbols/code-points');
require('unicode-9.0.0/Block/Alchemical_Symbols/symbols');
require('unicode-9.0.0/Block/Alchemical_Symbols/regex');

require('unicode-9.0.0/Block/Alphabetic_Presentation_Forms/code-points');
require('unicode-9.0.0/Block/Alphabetic_Presentation_Forms/symbols');
require('unicode-9.0.0/Block/Alphabetic_Presentation_Forms/regex');

require('unicode-9.0.0/Block/Anatolian_Hieroglyphs/code-points');
require('unicode-9.0.0/Block/Anatolian_Hieroglyphs/symbols');
require('unicode-9.0.0/Block/Anatolian_Hieroglyphs/regex');

require('unicode-9.0.0/Block/Ancient_Greek_Musical_Notation/code-points');
require('unicode-9.0.0/Block/Ancient_Greek_Musical_Notation/symbols');
require('unicode-9.0.0/Block/Ancient_Greek_Musical_Notation/regex');

require('unicode-9.0.0/Block/Ancient_Greek_Numbers/code-points');
require('unicode-9.0.0/Block/Ancient_Greek_Numbers/symbols');
require('unicode-9.0.0/Block/Ancient_Greek_Numbers/regex');

require('unicode-9.0.0/Block/Ancient_Symbols/code-points');
require('unicode-9.0.0/Block/Ancient_Symbols/symbols');
require('unicode-9.0.0/Block/Ancient_Symbols/regex');

require('unicode-9.0.0/Block/Arabic/code-points');
require('unicode-9.0.0/Block/Arabic/symbols');
require('unicode-9.0.0/Block/Arabic/regex');

require('unicode-9.0.0/Block/Arabic_Extended_A/code-points');
require('unicode-9.0.0/Block/Arabic_Extended_A/symbols');
require('unicode-9.0.0/Block/Arabic_Extended_A/regex');

require('unicode-9.0.0/Block/Arabic_Mathematical_Alphabetic_Symbols/code-points');
require('unicode-9.0.0/Block/Arabic_Mathematical_Alphabetic_Symbols/symbols');
require('unicode-9.0.0/Block/Arabic_Mathematical_Alphabetic_Symbols/regex');

require('unicode-9.0.0/Block/Arabic_Presentation_Forms_A/code-points');
require('unicode-9.0.0/Block/Arabic_Presentation_Forms_A/symbols');
require('unicode-9.0.0/Block/Arabic_Presentation_Forms_A/regex');

require('unicode-9.0.0/Block/Arabic_Presentation_Forms_B/code-points');
require('unicode-9.0.0/Block/Arabic_Presentation_Forms_B/symbols');
require('unicode-9.0.0/Block/Arabic_Presentation_Forms_B/regex');

require('unicode-9.0.0/Block/Arabic_Supplement/code-points');
require('unicode-9.0.0/Block/Arabic_Supplement/symbols');
require('unicode-9.0.0/Block/Arabic_Supplement/regex');

require('unicode-9.0.0/Block/Armenian/code-points');
require('unicode-9.0.0/Block/Armenian/symbols');
require('unicode-9.0.0/Block/Armenian/regex');

require('unicode-9.0.0/Block/Arrows/code-points');
require('unicode-9.0.0/Block/Arrows/symbols');
require('unicode-9.0.0/Block/Arrows/regex');

require('unicode-9.0.0/Block/Avestan/code-points');
require('unicode-9.0.0/Block/Avestan/symbols');
require('unicode-9.0.0/Block/Avestan/regex');

require('unicode-9.0.0/Block/Balinese/code-points');
require('unicode-9.0.0/Block/Balinese/symbols');
require('unicode-9.0.0/Block/Balinese/regex');

require('unicode-9.0.0/Block/Bamum/code-points');
require('unicode-9.0.0/Block/Bamum/symbols');
require('unicode-9.0.0/Block/Bamum/regex');

require('unicode-9.0.0/Block/Bamum_Supplement/code-points');
require('unicode-9.0.0/Block/Bamum_Supplement/symbols');
require('unicode-9.0.0/Block/Bamum_Supplement/regex');

require('unicode-9.0.0/Block/Basic_Latin/code-points');
require('unicode-9.0.0/Block/Basic_Latin/symbols');
require('unicode-9.0.0/Block/Basic_Latin/regex');

require('unicode-9.0.0/Block/Bassa_Vah/code-points');
require('unicode-9.0.0/Block/Bassa_Vah/symbols');
require('unicode-9.0.0/Block/Bassa_Vah/regex');

require('unicode-9.0.0/Block/Batak/code-points');
require('unicode-9.0.0/Block/Batak/symbols');
require('unicode-9.0.0/Block/Batak/regex');

require('unicode-9.0.0/Block/Bengali/code-points');
require('unicode-9.0.0/Block/Bengali/symbols');
require('unicode-9.0.0/Block/Bengali/regex');

require('unicode-9.0.0/Block/Bhaiksuki/code-points');
require('unicode-9.0.0/Block/Bhaiksuki/symbols');
require('unicode-9.0.0/Block/Bhaiksuki/regex');

require('unicode-9.0.0/Block/Block_Elements/code-points');
require('unicode-9.0.0/Block/Block_Elements/symbols');
require('unicode-9.0.0/Block/Block_Elements/regex');

require('unicode-9.0.0/Block/Bopomofo/code-points');
require('unicode-9.0.0/Block/Bopomofo/symbols');
require('unicode-9.0.0/Block/Bopomofo/regex');

require('unicode-9.0.0/Block/Bopomofo_Extended/code-points');
require('unicode-9.0.0/Block/Bopomofo_Extended/symbols');
require('unicode-9.0.0/Block/Bopomofo_Extended/regex');

require('unicode-9.0.0/Block/Box_Drawing/code-points');
require('unicode-9.0.0/Block/Box_Drawing/symbols');
require('unicode-9.0.0/Block/Box_Drawing/regex');

require('unicode-9.0.0/Block/Brahmi/code-points');
require('unicode-9.0.0/Block/Brahmi/symbols');
require('unicode-9.0.0/Block/Brahmi/regex');

require('unicode-9.0.0/Block/Braille_Patterns/code-points');
require('unicode-9.0.0/Block/Braille_Patterns/symbols');
require('unicode-9.0.0/Block/Braille_Patterns/regex');

require('unicode-9.0.0/Block/Buginese/code-points');
require('unicode-9.0.0/Block/Buginese/symbols');
require('unicode-9.0.0/Block/Buginese/regex');

require('unicode-9.0.0/Block/Buhid/code-points');
require('unicode-9.0.0/Block/Buhid/symbols');
require('unicode-9.0.0/Block/Buhid/regex');

require('unicode-9.0.0/Block/Byzantine_Musical_Symbols/code-points');
require('unicode-9.0.0/Block/Byzantine_Musical_Symbols/symbols');
require('unicode-9.0.0/Block/Byzantine_Musical_Symbols/regex');

require('unicode-9.0.0/Block/CJK_Compatibility/code-points');
require('unicode-9.0.0/Block/CJK_Compatibility/symbols');
require('unicode-9.0.0/Block/CJK_Compatibility/regex');

require('unicode-9.0.0/Block/CJK_Compatibility_Forms/code-points');
require('unicode-9.0.0/Block/CJK_Compatibility_Forms/symbols');
require('unicode-9.0.0/Block/CJK_Compatibility_Forms/regex');

require('unicode-9.0.0/Block/CJK_Compatibility_Ideographs/code-points');
require('unicode-9.0.0/Block/CJK_Compatibility_Ideographs/symbols');
require('unicode-9.0.0/Block/CJK_Compatibility_Ideographs/regex');

require('unicode-9.0.0/Block/CJK_Compatibility_Ideographs_Supplement/code-points');
require('unicode-9.0.0/Block/CJK_Compatibility_Ideographs_Supplement/symbols');
require('unicode-9.0.0/Block/CJK_Compatibility_Ideographs_Supplement/regex');

require('unicode-9.0.0/Block/CJK_Radicals_Supplement/code-points');
require('unicode-9.0.0/Block/CJK_Radicals_Supplement/symbols');
require('unicode-9.0.0/Block/CJK_Radicals_Supplement/regex');

require('unicode-9.0.0/Block/CJK_Strokes/code-points');
require('unicode-9.0.0/Block/CJK_Strokes/symbols');
require('unicode-9.0.0/Block/CJK_Strokes/regex');

require('unicode-9.0.0/Block/CJK_Symbols_And_Punctuation/code-points');
require('unicode-9.0.0/Block/CJK_Symbols_And_Punctuation/symbols');
require('unicode-9.0.0/Block/CJK_Symbols_And_Punctuation/regex');

require('unicode-9.0.0/Block/CJK_Unified_Ideographs/code-points');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs/symbols');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs/regex');

require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_A/code-points');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_A/symbols');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_A/regex');

require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_B/code-points');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_B/symbols');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_B/regex');

require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_C/code-points');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_C/symbols');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_C/regex');

require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_D/code-points');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_D/symbols');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_D/regex');

require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_E/code-points');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_E/symbols');
require('unicode-9.0.0/Block/CJK_Unified_Ideographs_Extension_E/regex');

require('unicode-9.0.0/Block/Carian/code-points');
require('unicode-9.0.0/Block/Carian/symbols');
require('unicode-9.0.0/Block/Carian/regex');

require('unicode-9.0.0/Block/Caucasian_Albanian/code-points');
require('unicode-9.0.0/Block/Caucasian_Albanian/symbols');
require('unicode-9.0.0/Block/Caucasian_Albanian/regex');

require('unicode-9.0.0/Block/Chakma/code-points');
require('unicode-9.0.0/Block/Chakma/symbols');
require('unicode-9.0.0/Block/Chakma/regex');

require('unicode-9.0.0/Block/Cham/code-points');
require('unicode-9.0.0/Block/Cham/symbols');
require('unicode-9.0.0/Block/Cham/regex');

require('unicode-9.0.0/Block/Cherokee/code-points');
require('unicode-9.0.0/Block/Cherokee/symbols');
require('unicode-9.0.0/Block/Cherokee/regex');

require('unicode-9.0.0/Block/Cherokee_Supplement/code-points');
require('unicode-9.0.0/Block/Cherokee_Supplement/symbols');
require('unicode-9.0.0/Block/Cherokee_Supplement/regex');

require('unicode-9.0.0/Block/Combining_Diacritical_Marks/code-points');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks/symbols');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks/regex');

require('unicode-9.0.0/Block/Combining_Diacritical_Marks_Extended/code-points');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks_Extended/symbols');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks_Extended/regex');

require('unicode-9.0.0/Block/Combining_Diacritical_Marks_For_Symbols/code-points');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks_For_Symbols/symbols');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks_For_Symbols/regex');

require('unicode-9.0.0/Block/Combining_Diacritical_Marks_Supplement/code-points');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks_Supplement/symbols');
require('unicode-9.0.0/Block/Combining_Diacritical_Marks_Supplement/regex');

require('unicode-9.0.0/Block/Combining_Half_Marks/code-points');
require('unicode-9.0.0/Block/Combining_Half_Marks/symbols');
require('unicode-9.0.0/Block/Combining_Half_Marks/regex');

require('unicode-9.0.0/Block/Common_Indic_Number_Forms/code-points');
require('unicode-9.0.0/Block/Common_Indic_Number_Forms/symbols');
require('unicode-9.0.0/Block/Common_Indic_Number_Forms/regex');

require('unicode-9.0.0/Block/Control_Pictures/code-points');
require('unicode-9.0.0/Block/Control_Pictures/symbols');
require('unicode-9.0.0/Block/Control_Pictures/regex');

require('unicode-9.0.0/Block/Coptic/code-points');
require('unicode-9.0.0/Block/Coptic/symbols');
require('unicode-9.0.0/Block/Coptic/regex');

require('unicode-9.0.0/Block/Coptic_Epact_Numbers/code-points');
require('unicode-9.0.0/Block/Coptic_Epact_Numbers/symbols');
require('unicode-9.0.0/Block/Coptic_Epact_Numbers/regex');

require('unicode-9.0.0/Block/Counting_Rod_Numerals/code-points');
require('unicode-9.0.0/Block/Counting_Rod_Numerals/symbols');
require('unicode-9.0.0/Block/Counting_Rod_Numerals/regex');

require('unicode-9.0.0/Block/Cuneiform/code-points');
require('unicode-9.0.0/Block/Cuneiform/symbols');
require('unicode-9.0.0/Block/Cuneiform/regex');

require('unicode-9.0.0/Block/Cuneiform_Numbers_And_Punctuation/code-points');
require('unicode-9.0.0/Block/Cuneiform_Numbers_And_Punctuation/symbols');
require('unicode-9.0.0/Block/Cuneiform_Numbers_And_Punctuation/regex');

require('unicode-9.0.0/Block/Currency_Symbols/code-points');
require('unicode-9.0.0/Block/Currency_Symbols/symbols');
require('unicode-9.0.0/Block/Currency_Symbols/regex');

require('unicode-9.0.0/Block/Cypriot_Syllabary/code-points');
require('unicode-9.0.0/Block/Cypriot_Syllabary/symbols');
require('unicode-9.0.0/Block/Cypriot_Syllabary/regex');

require('unicode-9.0.0/Block/Cyrillic/code-points');
require('unicode-9.0.0/Block/Cyrillic/symbols');
require('unicode-9.0.0/Block/Cyrillic/regex');

require('unicode-9.0.0/Block/Cyrillic_Extended_A/code-points');
require('unicode-9.0.0/Block/Cyrillic_Extended_A/symbols');
require('unicode-9.0.0/Block/Cyrillic_Extended_A/regex');

require('unicode-9.0.0/Block/Cyrillic_Extended_B/code-points');
require('unicode-9.0.0/Block/Cyrillic_Extended_B/symbols');
require('unicode-9.0.0/Block/Cyrillic_Extended_B/regex');

require('unicode-9.0.0/Block/Cyrillic_Extended_C/code-points');
require('unicode-9.0.0/Block/Cyrillic_Extended_C/symbols');
require('unicode-9.0.0/Block/Cyrillic_Extended_C/regex');

require('unicode-9.0.0/Block/Cyrillic_Supplement/code-points');
require('unicode-9.0.0/Block/Cyrillic_Supplement/symbols');
require('unicode-9.0.0/Block/Cyrillic_Supplement/regex');

require('unicode-9.0.0/Block/Deseret/code-points');
require('unicode-9.0.0/Block/Deseret/symbols');
require('unicode-9.0.0/Block/Deseret/regex');

require('unicode-9.0.0/Block/Devanagari/code-points');
require('unicode-9.0.0/Block/Devanagari/symbols');
require('unicode-9.0.0/Block/Devanagari/regex');

require('unicode-9.0.0/Block/Devanagari_Extended/code-points');
require('unicode-9.0.0/Block/Devanagari_Extended/symbols');
require('unicode-9.0.0/Block/Devanagari_Extended/regex');

require('unicode-9.0.0/Block/Dingbats/code-points');
require('unicode-9.0.0/Block/Dingbats/symbols');
require('unicode-9.0.0/Block/Dingbats/regex');

require('unicode-9.0.0/Block/Domino_Tiles/code-points');
require('unicode-9.0.0/Block/Domino_Tiles/symbols');
require('unicode-9.0.0/Block/Domino_Tiles/regex');

require('unicode-9.0.0/Block/Duployan/code-points');
require('unicode-9.0.0/Block/Duployan/symbols');
require('unicode-9.0.0/Block/Duployan/regex');

require('unicode-9.0.0/Block/Early_Dynastic_Cuneiform/code-points');
require('unicode-9.0.0/Block/Early_Dynastic_Cuneiform/symbols');
require('unicode-9.0.0/Block/Early_Dynastic_Cuneiform/regex');

require('unicode-9.0.0/Block/Egyptian_Hieroglyphs/code-points');
require('unicode-9.0.0/Block/Egyptian_Hieroglyphs/symbols');
require('unicode-9.0.0/Block/Egyptian_Hieroglyphs/regex');

require('unicode-9.0.0/Block/Elbasan/code-points');
require('unicode-9.0.0/Block/Elbasan/symbols');
require('unicode-9.0.0/Block/Elbasan/regex');

require('unicode-9.0.0/Block/Emoticons/code-points');
require('unicode-9.0.0/Block/Emoticons/symbols');
require('unicode-9.0.0/Block/Emoticons/regex');

require('unicode-9.0.0/Block/Enclosed_Alphanumeric_Supplement/code-points');
require('unicode-9.0.0/Block/Enclosed_Alphanumeric_Supplement/symbols');
require('unicode-9.0.0/Block/Enclosed_Alphanumeric_Supplement/regex');

require('unicode-9.0.0/Block/Enclosed_Alphanumerics/code-points');
require('unicode-9.0.0/Block/Enclosed_Alphanumerics/symbols');
require('unicode-9.0.0/Block/Enclosed_Alphanumerics/regex');

require('unicode-9.0.0/Block/Enclosed_CJK_Letters_And_Months/code-points');
require('unicode-9.0.0/Block/Enclosed_CJK_Letters_And_Months/symbols');
require('unicode-9.0.0/Block/Enclosed_CJK_Letters_And_Months/regex');

require('unicode-9.0.0/Block/Enclosed_Ideographic_Supplement/code-points');
require('unicode-9.0.0/Block/Enclosed_Ideographic_Supplement/symbols');
require('unicode-9.0.0/Block/Enclosed_Ideographic_Supplement/regex');

require('unicode-9.0.0/Block/Ethiopic/code-points');
require('unicode-9.0.0/Block/Ethiopic/symbols');
require('unicode-9.0.0/Block/Ethiopic/regex');

require('unicode-9.0.0/Block/Ethiopic_Extended/code-points');
require('unicode-9.0.0/Block/Ethiopic_Extended/symbols');
require('unicode-9.0.0/Block/Ethiopic_Extended/regex');

require('unicode-9.0.0/Block/Ethiopic_Extended_A/code-points');
require('unicode-9.0.0/Block/Ethiopic_Extended_A/symbols');
require('unicode-9.0.0/Block/Ethiopic_Extended_A/regex');

require('unicode-9.0.0/Block/Ethiopic_Supplement/code-points');
require('unicode-9.0.0/Block/Ethiopic_Supplement/symbols');
require('unicode-9.0.0/Block/Ethiopic_Supplement/regex');

require('unicode-9.0.0/Block/General_Punctuation/code-points');
require('unicode-9.0.0/Block/General_Punctuation/symbols');
require('unicode-9.0.0/Block/General_Punctuation/regex');

require('unicode-9.0.0/Block/Geometric_Shapes/code-points');
require('unicode-9.0.0/Block/Geometric_Shapes/symbols');
require('unicode-9.0.0/Block/Geometric_Shapes/regex');

require('unicode-9.0.0/Block/Geometric_Shapes_Extended/code-points');
require('unicode-9.0.0/Block/Geometric_Shapes_Extended/symbols');
require('unicode-9.0.0/Block/Geometric_Shapes_Extended/regex');

require('unicode-9.0.0/Block/Georgian/code-points');
require('unicode-9.0.0/Block/Georgian/symbols');
require('unicode-9.0.0/Block/Georgian/regex');

require('unicode-9.0.0/Block/Georgian_Supplement/code-points');
require('unicode-9.0.0/Block/Georgian_Supplement/symbols');
require('unicode-9.0.0/Block/Georgian_Supplement/regex');

require('unicode-9.0.0/Block/Glagolitic/code-points');
require('unicode-9.0.0/Block/Glagolitic/symbols');
require('unicode-9.0.0/Block/Glagolitic/regex');

require('unicode-9.0.0/Block/Glagolitic_Supplement/code-points');
require('unicode-9.0.0/Block/Glagolitic_Supplement/symbols');
require('unicode-9.0.0/Block/Glagolitic_Supplement/regex');

require('unicode-9.0.0/Block/Gothic/code-points');
require('unicode-9.0.0/Block/Gothic/symbols');
require('unicode-9.0.0/Block/Gothic/regex');

require('unicode-9.0.0/Block/Grantha/code-points');
require('unicode-9.0.0/Block/Grantha/symbols');
require('unicode-9.0.0/Block/Grantha/regex');

require('unicode-9.0.0/Block/Greek_And_Coptic/code-points');
require('unicode-9.0.0/Block/Greek_And_Coptic/symbols');
require('unicode-9.0.0/Block/Greek_And_Coptic/regex');

require('unicode-9.0.0/Block/Greek_Extended/code-points');
require('unicode-9.0.0/Block/Greek_Extended/symbols');
require('unicode-9.0.0/Block/Greek_Extended/regex');

require('unicode-9.0.0/Block/Gujarati/code-points');
require('unicode-9.0.0/Block/Gujarati/symbols');
require('unicode-9.0.0/Block/Gujarati/regex');

require('unicode-9.0.0/Block/Gurmukhi/code-points');
require('unicode-9.0.0/Block/Gurmukhi/symbols');
require('unicode-9.0.0/Block/Gurmukhi/regex');

require('unicode-9.0.0/Block/Halfwidth_And_Fullwidth_Forms/code-points');
require('unicode-9.0.0/Block/Halfwidth_And_Fullwidth_Forms/symbols');
require('unicode-9.0.0/Block/Halfwidth_And_Fullwidth_Forms/regex');

require('unicode-9.0.0/Block/Hangul_Compatibility_Jamo/code-points');
require('unicode-9.0.0/Block/Hangul_Compatibility_Jamo/symbols');
require('unicode-9.0.0/Block/Hangul_Compatibility_Jamo/regex');

require('unicode-9.0.0/Block/Hangul_Jamo/code-points');
require('unicode-9.0.0/Block/Hangul_Jamo/symbols');
require('unicode-9.0.0/Block/Hangul_Jamo/regex');

require('unicode-9.0.0/Block/Hangul_Jamo_Extended_A/code-points');
require('unicode-9.0.0/Block/Hangul_Jamo_Extended_A/symbols');
require('unicode-9.0.0/Block/Hangul_Jamo_Extended_A/regex');

require('unicode-9.0.0/Block/Hangul_Jamo_Extended_B/code-points');
require('unicode-9.0.0/Block/Hangul_Jamo_Extended_B/symbols');
require('unicode-9.0.0/Block/Hangul_Jamo_Extended_B/regex');

require('unicode-9.0.0/Block/Hangul_Syllables/code-points');
require('unicode-9.0.0/Block/Hangul_Syllables/symbols');
require('unicode-9.0.0/Block/Hangul_Syllables/regex');

require('unicode-9.0.0/Block/Hanunoo/code-points');
require('unicode-9.0.0/Block/Hanunoo/symbols');
require('unicode-9.0.0/Block/Hanunoo/regex');

require('unicode-9.0.0/Block/Hatran/code-points');
require('unicode-9.0.0/Block/Hatran/symbols');
require('unicode-9.0.0/Block/Hatran/regex');

require('unicode-9.0.0/Block/Hebrew/code-points');
require('unicode-9.0.0/Block/Hebrew/symbols');
require('unicode-9.0.0/Block/Hebrew/regex');

require('unicode-9.0.0/Block/High_Private_Use_Surrogates/code-points');
require('unicode-9.0.0/Block/High_Private_Use_Surrogates/symbols');
require('unicode-9.0.0/Block/High_Private_Use_Surrogates/regex');

require('unicode-9.0.0/Block/High_Surrogates/code-points');
require('unicode-9.0.0/Block/High_Surrogates/symbols');
require('unicode-9.0.0/Block/High_Surrogates/regex');

require('unicode-9.0.0/Block/Hiragana/code-points');
require('unicode-9.0.0/Block/Hiragana/symbols');
require('unicode-9.0.0/Block/Hiragana/regex');

require('unicode-9.0.0/Block/IPA_Extensions/code-points');
require('unicode-9.0.0/Block/IPA_Extensions/symbols');
require('unicode-9.0.0/Block/IPA_Extensions/regex');

require('unicode-9.0.0/Block/Ideographic_Description_Characters/code-points');
require('unicode-9.0.0/Block/Ideographic_Description_Characters/symbols');
require('unicode-9.0.0/Block/Ideographic_Description_Characters/regex');

require('unicode-9.0.0/Block/Ideographic_Symbols_And_Punctuation/code-points');
require('unicode-9.0.0/Block/Ideographic_Symbols_And_Punctuation/symbols');
require('unicode-9.0.0/Block/Ideographic_Symbols_And_Punctuation/regex');

require('unicode-9.0.0/Block/Imperial_Aramaic/code-points');
require('unicode-9.0.0/Block/Imperial_Aramaic/symbols');
require('unicode-9.0.0/Block/Imperial_Aramaic/regex');

require('unicode-9.0.0/Block/Inscriptional_Pahlavi/code-points');
require('unicode-9.0.0/Block/Inscriptional_Pahlavi/symbols');
require('unicode-9.0.0/Block/Inscriptional_Pahlavi/regex');

require('unicode-9.0.0/Block/Inscriptional_Parthian/code-points');
require('unicode-9.0.0/Block/Inscriptional_Parthian/symbols');
require('unicode-9.0.0/Block/Inscriptional_Parthian/regex');

require('unicode-9.0.0/Block/Javanese/code-points');
require('unicode-9.0.0/Block/Javanese/symbols');
require('unicode-9.0.0/Block/Javanese/regex');

require('unicode-9.0.0/Block/Kaithi/code-points');
require('unicode-9.0.0/Block/Kaithi/symbols');
require('unicode-9.0.0/Block/Kaithi/regex');

require('unicode-9.0.0/Block/Kana_Supplement/code-points');
require('unicode-9.0.0/Block/Kana_Supplement/symbols');
require('unicode-9.0.0/Block/Kana_Supplement/regex');

require('unicode-9.0.0/Block/Kanbun/code-points');
require('unicode-9.0.0/Block/Kanbun/symbols');
require('unicode-9.0.0/Block/Kanbun/regex');

require('unicode-9.0.0/Block/Kangxi_Radicals/code-points');
require('unicode-9.0.0/Block/Kangxi_Radicals/symbols');
require('unicode-9.0.0/Block/Kangxi_Radicals/regex');

require('unicode-9.0.0/Block/Kannada/code-points');
require('unicode-9.0.0/Block/Kannada/symbols');
require('unicode-9.0.0/Block/Kannada/regex');

require('unicode-9.0.0/Block/Katakana/code-points');
require('unicode-9.0.0/Block/Katakana/symbols');
require('unicode-9.0.0/Block/Katakana/regex');

require('unicode-9.0.0/Block/Katakana_Phonetic_Extensions/code-points');
require('unicode-9.0.0/Block/Katakana_Phonetic_Extensions/symbols');
require('unicode-9.0.0/Block/Katakana_Phonetic_Extensions/regex');

require('unicode-9.0.0/Block/Kayah_Li/code-points');
require('unicode-9.0.0/Block/Kayah_Li/symbols');
require('unicode-9.0.0/Block/Kayah_Li/regex');

require('unicode-9.0.0/Block/Kharoshthi/code-points');
require('unicode-9.0.0/Block/Kharoshthi/symbols');
require('unicode-9.0.0/Block/Kharoshthi/regex');

require('unicode-9.0.0/Block/Khmer/code-points');
require('unicode-9.0.0/Block/Khmer/symbols');
require('unicode-9.0.0/Block/Khmer/regex');

require('unicode-9.0.0/Block/Khmer_Symbols/code-points');
require('unicode-9.0.0/Block/Khmer_Symbols/symbols');
require('unicode-9.0.0/Block/Khmer_Symbols/regex');

require('unicode-9.0.0/Block/Khojki/code-points');
require('unicode-9.0.0/Block/Khojki/symbols');
require('unicode-9.0.0/Block/Khojki/regex');

require('unicode-9.0.0/Block/Khudawadi/code-points');
require('unicode-9.0.0/Block/Khudawadi/symbols');
require('unicode-9.0.0/Block/Khudawadi/regex');

require('unicode-9.0.0/Block/Lao/code-points');
require('unicode-9.0.0/Block/Lao/symbols');
require('unicode-9.0.0/Block/Lao/regex');

require('unicode-9.0.0/Block/Latin_1_Supplement/code-points');
require('unicode-9.0.0/Block/Latin_1_Supplement/symbols');
require('unicode-9.0.0/Block/Latin_1_Supplement/regex');

require('unicode-9.0.0/Block/Latin_Extended_A/code-points');
require('unicode-9.0.0/Block/Latin_Extended_A/symbols');
require('unicode-9.0.0/Block/Latin_Extended_A/regex');

require('unicode-9.0.0/Block/Latin_Extended_Additional/code-points');
require('unicode-9.0.0/Block/Latin_Extended_Additional/symbols');
require('unicode-9.0.0/Block/Latin_Extended_Additional/regex');

require('unicode-9.0.0/Block/Latin_Extended_B/code-points');
require('unicode-9.0.0/Block/Latin_Extended_B/symbols');
require('unicode-9.0.0/Block/Latin_Extended_B/regex');

require('unicode-9.0.0/Block/Latin_Extended_C/code-points');
require('unicode-9.0.0/Block/Latin_Extended_C/symbols');
require('unicode-9.0.0/Block/Latin_Extended_C/regex');

require('unicode-9.0.0/Block/Latin_Extended_D/code-points');
require('unicode-9.0.0/Block/Latin_Extended_D/symbols');
require('unicode-9.0.0/Block/Latin_Extended_D/regex');

require('unicode-9.0.0/Block/Latin_Extended_E/code-points');
require('unicode-9.0.0/Block/Latin_Extended_E/symbols');
require('unicode-9.0.0/Block/Latin_Extended_E/regex');

require('unicode-9.0.0/Block/Lepcha/code-points');
require('unicode-9.0.0/Block/Lepcha/symbols');
require('unicode-9.0.0/Block/Lepcha/regex');

require('unicode-9.0.0/Block/Letterlike_Symbols/code-points');
require('unicode-9.0.0/Block/Letterlike_Symbols/symbols');
require('unicode-9.0.0/Block/Letterlike_Symbols/regex');

require('unicode-9.0.0/Block/Limbu/code-points');
require('unicode-9.0.0/Block/Limbu/symbols');
require('unicode-9.0.0/Block/Limbu/regex');

require('unicode-9.0.0/Block/Linear_A/code-points');
require('unicode-9.0.0/Block/Linear_A/symbols');
require('unicode-9.0.0/Block/Linear_A/regex');

require('unicode-9.0.0/Block/Linear_B_Ideograms/code-points');
require('unicode-9.0.0/Block/Linear_B_Ideograms/symbols');
require('unicode-9.0.0/Block/Linear_B_Ideograms/regex');

require('unicode-9.0.0/Block/Linear_B_Syllabary/code-points');
require('unicode-9.0.0/Block/Linear_B_Syllabary/symbols');
require('unicode-9.0.0/Block/Linear_B_Syllabary/regex');

require('unicode-9.0.0/Block/Lisu/code-points');
require('unicode-9.0.0/Block/Lisu/symbols');
require('unicode-9.0.0/Block/Lisu/regex');

require('unicode-9.0.0/Block/Low_Surrogates/code-points');
require('unicode-9.0.0/Block/Low_Surrogates/symbols');
require('unicode-9.0.0/Block/Low_Surrogates/regex');

require('unicode-9.0.0/Block/Lycian/code-points');
require('unicode-9.0.0/Block/Lycian/symbols');
require('unicode-9.0.0/Block/Lycian/regex');

require('unicode-9.0.0/Block/Lydian/code-points');
require('unicode-9.0.0/Block/Lydian/symbols');
require('unicode-9.0.0/Block/Lydian/regex');

require('unicode-9.0.0/Block/Mahajani/code-points');
require('unicode-9.0.0/Block/Mahajani/symbols');
require('unicode-9.0.0/Block/Mahajani/regex');

require('unicode-9.0.0/Block/Mahjong_Tiles/code-points');
require('unicode-9.0.0/Block/Mahjong_Tiles/symbols');
require('unicode-9.0.0/Block/Mahjong_Tiles/regex');

require('unicode-9.0.0/Block/Malayalam/code-points');
require('unicode-9.0.0/Block/Malayalam/symbols');
require('unicode-9.0.0/Block/Malayalam/regex');

require('unicode-9.0.0/Block/Mandaic/code-points');
require('unicode-9.0.0/Block/Mandaic/symbols');
require('unicode-9.0.0/Block/Mandaic/regex');

require('unicode-9.0.0/Block/Manichaean/code-points');
require('unicode-9.0.0/Block/Manichaean/symbols');
require('unicode-9.0.0/Block/Manichaean/regex');

require('unicode-9.0.0/Block/Marchen/code-points');
require('unicode-9.0.0/Block/Marchen/symbols');
require('unicode-9.0.0/Block/Marchen/regex');

require('unicode-9.0.0/Block/Mathematical_Alphanumeric_Symbols/code-points');
require('unicode-9.0.0/Block/Mathematical_Alphanumeric_Symbols/symbols');
require('unicode-9.0.0/Block/Mathematical_Alphanumeric_Symbols/regex');

require('unicode-9.0.0/Block/Mathematical_Operators/code-points');
require('unicode-9.0.0/Block/Mathematical_Operators/symbols');
require('unicode-9.0.0/Block/Mathematical_Operators/regex');

require('unicode-9.0.0/Block/Meetei_Mayek/code-points');
require('unicode-9.0.0/Block/Meetei_Mayek/symbols');
require('unicode-9.0.0/Block/Meetei_Mayek/regex');

require('unicode-9.0.0/Block/Meetei_Mayek_Extensions/code-points');
require('unicode-9.0.0/Block/Meetei_Mayek_Extensions/symbols');
require('unicode-9.0.0/Block/Meetei_Mayek_Extensions/regex');

require('unicode-9.0.0/Block/Mende_Kikakui/code-points');
require('unicode-9.0.0/Block/Mende_Kikakui/symbols');
require('unicode-9.0.0/Block/Mende_Kikakui/regex');

require('unicode-9.0.0/Block/Meroitic_Cursive/code-points');
require('unicode-9.0.0/Block/Meroitic_Cursive/symbols');
require('unicode-9.0.0/Block/Meroitic_Cursive/regex');

require('unicode-9.0.0/Block/Meroitic_Hieroglyphs/code-points');
require('unicode-9.0.0/Block/Meroitic_Hieroglyphs/symbols');
require('unicode-9.0.0/Block/Meroitic_Hieroglyphs/regex');

require('unicode-9.0.0/Block/Miao/code-points');
require('unicode-9.0.0/Block/Miao/symbols');
require('unicode-9.0.0/Block/Miao/regex');

require('unicode-9.0.0/Block/Miscellaneous_Mathematical_Symbols_A/code-points');
require('unicode-9.0.0/Block/Miscellaneous_Mathematical_Symbols_A/symbols');
require('unicode-9.0.0/Block/Miscellaneous_Mathematical_Symbols_A/regex');

require('unicode-9.0.0/Block/Miscellaneous_Mathematical_Symbols_B/code-points');
require('unicode-9.0.0/Block/Miscellaneous_Mathematical_Symbols_B/symbols');
require('unicode-9.0.0/Block/Miscellaneous_Mathematical_Symbols_B/regex');

require('unicode-9.0.0/Block/Miscellaneous_Symbols/code-points');
require('unicode-9.0.0/Block/Miscellaneous_Symbols/symbols');
require('unicode-9.0.0/Block/Miscellaneous_Symbols/regex');

require('unicode-9.0.0/Block/Miscellaneous_Symbols_And_Arrows/code-points');
require('unicode-9.0.0/Block/Miscellaneous_Symbols_And_Arrows/symbols');
require('unicode-9.0.0/Block/Miscellaneous_Symbols_And_Arrows/regex');

require('unicode-9.0.0/Block/Miscellaneous_Symbols_And_Pictographs/code-points');
require('unicode-9.0.0/Block/Miscellaneous_Symbols_And_Pictographs/symbols');
require('unicode-9.0.0/Block/Miscellaneous_Symbols_And_Pictographs/regex');

require('unicode-9.0.0/Block/Miscellaneous_Technical/code-points');
require('unicode-9.0.0/Block/Miscellaneous_Technical/symbols');
require('unicode-9.0.0/Block/Miscellaneous_Technical/regex');

require('unicode-9.0.0/Block/Modi/code-points');
require('unicode-9.0.0/Block/Modi/symbols');
require('unicode-9.0.0/Block/Modi/regex');

require('unicode-9.0.0/Block/Modifier_Tone_Letters/code-points');
require('unicode-9.0.0/Block/Modifier_Tone_Letters/symbols');
require('unicode-9.0.0/Block/Modifier_Tone_Letters/regex');

require('unicode-9.0.0/Block/Mongolian/code-points');
require('unicode-9.0.0/Block/Mongolian/symbols');
require('unicode-9.0.0/Block/Mongolian/regex');

require('unicode-9.0.0/Block/Mongolian_Supplement/code-points');
require('unicode-9.0.0/Block/Mongolian_Supplement/symbols');
require('unicode-9.0.0/Block/Mongolian_Supplement/regex');

require('unicode-9.0.0/Block/Mro/code-points');
require('unicode-9.0.0/Block/Mro/symbols');
require('unicode-9.0.0/Block/Mro/regex');

require('unicode-9.0.0/Block/Multani/code-points');
require('unicode-9.0.0/Block/Multani/symbols');
require('unicode-9.0.0/Block/Multani/regex');

require('unicode-9.0.0/Block/Musical_Symbols/code-points');
require('unicode-9.0.0/Block/Musical_Symbols/symbols');
require('unicode-9.0.0/Block/Musical_Symbols/regex');

require('unicode-9.0.0/Block/Myanmar/code-points');
require('unicode-9.0.0/Block/Myanmar/symbols');
require('unicode-9.0.0/Block/Myanmar/regex');

require('unicode-9.0.0/Block/Myanmar_Extended_A/code-points');
require('unicode-9.0.0/Block/Myanmar_Extended_A/symbols');
require('unicode-9.0.0/Block/Myanmar_Extended_A/regex');

require('unicode-9.0.0/Block/Myanmar_Extended_B/code-points');
require('unicode-9.0.0/Block/Myanmar_Extended_B/symbols');
require('unicode-9.0.0/Block/Myanmar_Extended_B/regex');

require('unicode-9.0.0/Block/NKo/code-points');
require('unicode-9.0.0/Block/NKo/symbols');
require('unicode-9.0.0/Block/NKo/regex');

require('unicode-9.0.0/Block/Nabataean/code-points');
require('unicode-9.0.0/Block/Nabataean/symbols');
require('unicode-9.0.0/Block/Nabataean/regex');

require('unicode-9.0.0/Block/New_Tai_Lue/code-points');
require('unicode-9.0.0/Block/New_Tai_Lue/symbols');
require('unicode-9.0.0/Block/New_Tai_Lue/regex');

require('unicode-9.0.0/Block/Newa/code-points');
require('unicode-9.0.0/Block/Newa/symbols');
require('unicode-9.0.0/Block/Newa/regex');

require('unicode-9.0.0/Block/Number_Forms/code-points');
require('unicode-9.0.0/Block/Number_Forms/symbols');
require('unicode-9.0.0/Block/Number_Forms/regex');

require('unicode-9.0.0/Block/Ogham/code-points');
require('unicode-9.0.0/Block/Ogham/symbols');
require('unicode-9.0.0/Block/Ogham/regex');

require('unicode-9.0.0/Block/Ol_Chiki/code-points');
require('unicode-9.0.0/Block/Ol_Chiki/symbols');
require('unicode-9.0.0/Block/Ol_Chiki/regex');

require('unicode-9.0.0/Block/Old_Hungarian/code-points');
require('unicode-9.0.0/Block/Old_Hungarian/symbols');
require('unicode-9.0.0/Block/Old_Hungarian/regex');

require('unicode-9.0.0/Block/Old_Italic/code-points');
require('unicode-9.0.0/Block/Old_Italic/symbols');
require('unicode-9.0.0/Block/Old_Italic/regex');

require('unicode-9.0.0/Block/Old_North_Arabian/code-points');
require('unicode-9.0.0/Block/Old_North_Arabian/symbols');
require('unicode-9.0.0/Block/Old_North_Arabian/regex');

require('unicode-9.0.0/Block/Old_Permic/code-points');
require('unicode-9.0.0/Block/Old_Permic/symbols');
require('unicode-9.0.0/Block/Old_Permic/regex');

require('unicode-9.0.0/Block/Old_Persian/code-points');
require('unicode-9.0.0/Block/Old_Persian/symbols');
require('unicode-9.0.0/Block/Old_Persian/regex');

require('unicode-9.0.0/Block/Old_South_Arabian/code-points');
require('unicode-9.0.0/Block/Old_South_Arabian/symbols');
require('unicode-9.0.0/Block/Old_South_Arabian/regex');

require('unicode-9.0.0/Block/Old_Turkic/code-points');
require('unicode-9.0.0/Block/Old_Turkic/symbols');
require('unicode-9.0.0/Block/Old_Turkic/regex');

require('unicode-9.0.0/Block/Optical_Character_Recognition/code-points');
require('unicode-9.0.0/Block/Optical_Character_Recognition/symbols');
require('unicode-9.0.0/Block/Optical_Character_Recognition/regex');

require('unicode-9.0.0/Block/Oriya/code-points');
require('unicode-9.0.0/Block/Oriya/symbols');
require('unicode-9.0.0/Block/Oriya/regex');

require('unicode-9.0.0/Block/Ornamental_Dingbats/code-points');
require('unicode-9.0.0/Block/Ornamental_Dingbats/symbols');
require('unicode-9.0.0/Block/Ornamental_Dingbats/regex');

require('unicode-9.0.0/Block/Osage/code-points');
require('unicode-9.0.0/Block/Osage/symbols');
require('unicode-9.0.0/Block/Osage/regex');

require('unicode-9.0.0/Block/Osmanya/code-points');
require('unicode-9.0.0/Block/Osmanya/symbols');
require('unicode-9.0.0/Block/Osmanya/regex');

require('unicode-9.0.0/Block/Pahawh_Hmong/code-points');
require('unicode-9.0.0/Block/Pahawh_Hmong/symbols');
require('unicode-9.0.0/Block/Pahawh_Hmong/regex');

require('unicode-9.0.0/Block/Palmyrene/code-points');
require('unicode-9.0.0/Block/Palmyrene/symbols');
require('unicode-9.0.0/Block/Palmyrene/regex');

require('unicode-9.0.0/Block/Pau_Cin_Hau/code-points');
require('unicode-9.0.0/Block/Pau_Cin_Hau/symbols');
require('unicode-9.0.0/Block/Pau_Cin_Hau/regex');

require('unicode-9.0.0/Block/Phags_Pa/code-points');
require('unicode-9.0.0/Block/Phags_Pa/symbols');
require('unicode-9.0.0/Block/Phags_Pa/regex');

require('unicode-9.0.0/Block/Phaistos_Disc/code-points');
require('unicode-9.0.0/Block/Phaistos_Disc/symbols');
require('unicode-9.0.0/Block/Phaistos_Disc/regex');

require('unicode-9.0.0/Block/Phoenician/code-points');
require('unicode-9.0.0/Block/Phoenician/symbols');
require('unicode-9.0.0/Block/Phoenician/regex');

require('unicode-9.0.0/Block/Phonetic_Extensions/code-points');
require('unicode-9.0.0/Block/Phonetic_Extensions/symbols');
require('unicode-9.0.0/Block/Phonetic_Extensions/regex');

require('unicode-9.0.0/Block/Phonetic_Extensions_Supplement/code-points');
require('unicode-9.0.0/Block/Phonetic_Extensions_Supplement/symbols');
require('unicode-9.0.0/Block/Phonetic_Extensions_Supplement/regex');

require('unicode-9.0.0/Block/Playing_Cards/code-points');
require('unicode-9.0.0/Block/Playing_Cards/symbols');
require('unicode-9.0.0/Block/Playing_Cards/regex');

require('unicode-9.0.0/Block/Private_Use_Area/code-points');
require('unicode-9.0.0/Block/Private_Use_Area/symbols');
require('unicode-9.0.0/Block/Private_Use_Area/regex');

require('unicode-9.0.0/Block/Psalter_Pahlavi/code-points');
require('unicode-9.0.0/Block/Psalter_Pahlavi/symbols');
require('unicode-9.0.0/Block/Psalter_Pahlavi/regex');

require('unicode-9.0.0/Block/Rejang/code-points');
require('unicode-9.0.0/Block/Rejang/symbols');
require('unicode-9.0.0/Block/Rejang/regex');

require('unicode-9.0.0/Block/Rumi_Numeral_Symbols/code-points');
require('unicode-9.0.0/Block/Rumi_Numeral_Symbols/symbols');
require('unicode-9.0.0/Block/Rumi_Numeral_Symbols/regex');

require('unicode-9.0.0/Block/Runic/code-points');
require('unicode-9.0.0/Block/Runic/symbols');
require('unicode-9.0.0/Block/Runic/regex');

require('unicode-9.0.0/Block/Samaritan/code-points');
require('unicode-9.0.0/Block/Samaritan/symbols');
require('unicode-9.0.0/Block/Samaritan/regex');

require('unicode-9.0.0/Block/Saurashtra/code-points');
require('unicode-9.0.0/Block/Saurashtra/symbols');
require('unicode-9.0.0/Block/Saurashtra/regex');

require('unicode-9.0.0/Block/Sharada/code-points');
require('unicode-9.0.0/Block/Sharada/symbols');
require('unicode-9.0.0/Block/Sharada/regex');

require('unicode-9.0.0/Block/Shavian/code-points');
require('unicode-9.0.0/Block/Shavian/symbols');
require('unicode-9.0.0/Block/Shavian/regex');

require('unicode-9.0.0/Block/Shorthand_Format_Controls/code-points');
require('unicode-9.0.0/Block/Shorthand_Format_Controls/symbols');
require('unicode-9.0.0/Block/Shorthand_Format_Controls/regex');

require('unicode-9.0.0/Block/Siddham/code-points');
require('unicode-9.0.0/Block/Siddham/symbols');
require('unicode-9.0.0/Block/Siddham/regex');

require('unicode-9.0.0/Block/Sinhala/code-points');
require('unicode-9.0.0/Block/Sinhala/symbols');
require('unicode-9.0.0/Block/Sinhala/regex');

require('unicode-9.0.0/Block/Sinhala_Archaic_Numbers/code-points');
require('unicode-9.0.0/Block/Sinhala_Archaic_Numbers/symbols');
require('unicode-9.0.0/Block/Sinhala_Archaic_Numbers/regex');

require('unicode-9.0.0/Block/Small_Form_Variants/code-points');
require('unicode-9.0.0/Block/Small_Form_Variants/symbols');
require('unicode-9.0.0/Block/Small_Form_Variants/regex');

require('unicode-9.0.0/Block/Sora_Sompeng/code-points');
require('unicode-9.0.0/Block/Sora_Sompeng/symbols');
require('unicode-9.0.0/Block/Sora_Sompeng/regex');

require('unicode-9.0.0/Block/Spacing_Modifier_Letters/code-points');
require('unicode-9.0.0/Block/Spacing_Modifier_Letters/symbols');
require('unicode-9.0.0/Block/Spacing_Modifier_Letters/regex');

require('unicode-9.0.0/Block/Specials/code-points');
require('unicode-9.0.0/Block/Specials/symbols');
require('unicode-9.0.0/Block/Specials/regex');

require('unicode-9.0.0/Block/Sundanese/code-points');
require('unicode-9.0.0/Block/Sundanese/symbols');
require('unicode-9.0.0/Block/Sundanese/regex');

require('unicode-9.0.0/Block/Sundanese_Supplement/code-points');
require('unicode-9.0.0/Block/Sundanese_Supplement/symbols');
require('unicode-9.0.0/Block/Sundanese_Supplement/regex');

require('unicode-9.0.0/Block/Superscripts_And_Subscripts/code-points');
require('unicode-9.0.0/Block/Superscripts_And_Subscripts/symbols');
require('unicode-9.0.0/Block/Superscripts_And_Subscripts/regex');

require('unicode-9.0.0/Block/Supplemental_Arrows_A/code-points');
require('unicode-9.0.0/Block/Supplemental_Arrows_A/symbols');
require('unicode-9.0.0/Block/Supplemental_Arrows_A/regex');

require('unicode-9.0.0/Block/Supplemental_Arrows_B/code-points');
require('unicode-9.0.0/Block/Supplemental_Arrows_B/symbols');
require('unicode-9.0.0/Block/Supplemental_Arrows_B/regex');

require('unicode-9.0.0/Block/Supplemental_Arrows_C/code-points');
require('unicode-9.0.0/Block/Supplemental_Arrows_C/symbols');
require('unicode-9.0.0/Block/Supplemental_Arrows_C/regex');

require('unicode-9.0.0/Block/Supplemental_Mathematical_Operators/code-points');
require('unicode-9.0.0/Block/Supplemental_Mathematical_Operators/symbols');
require('unicode-9.0.0/Block/Supplemental_Mathematical_Operators/regex');

require('unicode-9.0.0/Block/Supplemental_Punctuation/code-points');
require('unicode-9.0.0/Block/Supplemental_Punctuation/symbols');
require('unicode-9.0.0/Block/Supplemental_Punctuation/regex');

require('unicode-9.0.0/Block/Supplemental_Symbols_And_Pictographs/code-points');
require('unicode-9.0.0/Block/Supplemental_Symbols_And_Pictographs/symbols');
require('unicode-9.0.0/Block/Supplemental_Symbols_And_Pictographs/regex');

require('unicode-9.0.0/Block/Supplementary_Private_Use_Area_A/code-points');
require('unicode-9.0.0/Block/Supplementary_Private_Use_Area_A/symbols');
require('unicode-9.0.0/Block/Supplementary_Private_Use_Area_A/regex');

require('unicode-9.0.0/Block/Supplementary_Private_Use_Area_B/code-points');
require('unicode-9.0.0/Block/Supplementary_Private_Use_Area_B/symbols');
require('unicode-9.0.0/Block/Supplementary_Private_Use_Area_B/regex');

require('unicode-9.0.0/Block/Sutton_SignWriting/code-points');
require('unicode-9.0.0/Block/Sutton_SignWriting/symbols');
require('unicode-9.0.0/Block/Sutton_SignWriting/regex');

require('unicode-9.0.0/Block/Syloti_Nagri/code-points');
require('unicode-9.0.0/Block/Syloti_Nagri/symbols');
require('unicode-9.0.0/Block/Syloti_Nagri/regex');

require('unicode-9.0.0/Block/Syriac/code-points');
require('unicode-9.0.0/Block/Syriac/symbols');
require('unicode-9.0.0/Block/Syriac/regex');

require('unicode-9.0.0/Block/Tagalog/code-points');
require('unicode-9.0.0/Block/Tagalog/symbols');
require('unicode-9.0.0/Block/Tagalog/regex');

require('unicode-9.0.0/Block/Tagbanwa/code-points');
require('unicode-9.0.0/Block/Tagbanwa/symbols');
require('unicode-9.0.0/Block/Tagbanwa/regex');

require('unicode-9.0.0/Block/Tags/code-points');
require('unicode-9.0.0/Block/Tags/symbols');
require('unicode-9.0.0/Block/Tags/regex');

require('unicode-9.0.0/Block/Tai_Le/code-points');
require('unicode-9.0.0/Block/Tai_Le/symbols');
require('unicode-9.0.0/Block/Tai_Le/regex');

require('unicode-9.0.0/Block/Tai_Tham/code-points');
require('unicode-9.0.0/Block/Tai_Tham/symbols');
require('unicode-9.0.0/Block/Tai_Tham/regex');

require('unicode-9.0.0/Block/Tai_Viet/code-points');
require('unicode-9.0.0/Block/Tai_Viet/symbols');
require('unicode-9.0.0/Block/Tai_Viet/regex');

require('unicode-9.0.0/Block/Tai_Xuan_Jing_Symbols/code-points');
require('unicode-9.0.0/Block/Tai_Xuan_Jing_Symbols/symbols');
require('unicode-9.0.0/Block/Tai_Xuan_Jing_Symbols/regex');

require('unicode-9.0.0/Block/Takri/code-points');
require('unicode-9.0.0/Block/Takri/symbols');
require('unicode-9.0.0/Block/Takri/regex');

require('unicode-9.0.0/Block/Tamil/code-points');
require('unicode-9.0.0/Block/Tamil/symbols');
require('unicode-9.0.0/Block/Tamil/regex');

require('unicode-9.0.0/Block/Tangut/code-points');
require('unicode-9.0.0/Block/Tangut/symbols');
require('unicode-9.0.0/Block/Tangut/regex');

require('unicode-9.0.0/Block/Tangut_Components/code-points');
require('unicode-9.0.0/Block/Tangut_Components/symbols');
require('unicode-9.0.0/Block/Tangut_Components/regex');

require('unicode-9.0.0/Block/Telugu/code-points');
require('unicode-9.0.0/Block/Telugu/symbols');
require('unicode-9.0.0/Block/Telugu/regex');

require('unicode-9.0.0/Block/Thaana/code-points');
require('unicode-9.0.0/Block/Thaana/symbols');
require('unicode-9.0.0/Block/Thaana/regex');

require('unicode-9.0.0/Block/Thai/code-points');
require('unicode-9.0.0/Block/Thai/symbols');
require('unicode-9.0.0/Block/Thai/regex');

require('unicode-9.0.0/Block/Tibetan/code-points');
require('unicode-9.0.0/Block/Tibetan/symbols');
require('unicode-9.0.0/Block/Tibetan/regex');

require('unicode-9.0.0/Block/Tifinagh/code-points');
require('unicode-9.0.0/Block/Tifinagh/symbols');
require('unicode-9.0.0/Block/Tifinagh/regex');

require('unicode-9.0.0/Block/Tirhuta/code-points');
require('unicode-9.0.0/Block/Tirhuta/symbols');
require('unicode-9.0.0/Block/Tirhuta/regex');

require('unicode-9.0.0/Block/Transport_And_Map_Symbols/code-points');
require('unicode-9.0.0/Block/Transport_And_Map_Symbols/symbols');
require('unicode-9.0.0/Block/Transport_And_Map_Symbols/regex');

require('unicode-9.0.0/Block/Ugaritic/code-points');
require('unicode-9.0.0/Block/Ugaritic/symbols');
require('unicode-9.0.0/Block/Ugaritic/regex');

require('unicode-9.0.0/Block/Unified_Canadian_Aboriginal_Syllabics/code-points');
require('unicode-9.0.0/Block/Unified_Canadian_Aboriginal_Syllabics/symbols');
require('unicode-9.0.0/Block/Unified_Canadian_Aboriginal_Syllabics/regex');

require('unicode-9.0.0/Block/Unified_Canadian_Aboriginal_Syllabics_Extended/code-points');
require('unicode-9.0.0/Block/Unified_Canadian_Aboriginal_Syllabics_Extended/symbols');
require('unicode-9.0.0/Block/Unified_Canadian_Aboriginal_Syllabics_Extended/regex');

require('unicode-9.0.0/Block/Vai/code-points');
require('unicode-9.0.0/Block/Vai/symbols');
require('unicode-9.0.0/Block/Vai/regex');

require('unicode-9.0.0/Block/Variation_Selectors/code-points');
require('unicode-9.0.0/Block/Variation_Selectors/symbols');
require('unicode-9.0.0/Block/Variation_Selectors/regex');

require('unicode-9.0.0/Block/Variation_Selectors_Supplement/code-points');
require('unicode-9.0.0/Block/Variation_Selectors_Supplement/symbols');
require('unicode-9.0.0/Block/Variation_Selectors_Supplement/regex');

require('unicode-9.0.0/Block/Vedic_Extensions/code-points');
require('unicode-9.0.0/Block/Vedic_Extensions/symbols');
require('unicode-9.0.0/Block/Vedic_Extensions/regex');

require('unicode-9.0.0/Block/Vertical_Forms/code-points');
require('unicode-9.0.0/Block/Vertical_Forms/symbols');
require('unicode-9.0.0/Block/Vertical_Forms/regex');

require('unicode-9.0.0/Block/Warang_Citi/code-points');
require('unicode-9.0.0/Block/Warang_Citi/symbols');
require('unicode-9.0.0/Block/Warang_Citi/regex');

require('unicode-9.0.0/Block/Yi_Radicals/code-points');
require('unicode-9.0.0/Block/Yi_Radicals/symbols');
require('unicode-9.0.0/Block/Yi_Radicals/regex');

require('unicode-9.0.0/Block/Yi_Syllables/code-points');
require('unicode-9.0.0/Block/Yi_Syllables/symbols');
require('unicode-9.0.0/Block/Yi_Syllables/regex');

require('unicode-9.0.0/Block/Yijing_Hexagram_Symbols/code-points');
require('unicode-9.0.0/Block/Yijing_Hexagram_Symbols/symbols');
require('unicode-9.0.0/Block/Yijing_Hexagram_Symbols/regex');

// `Bidi_Mirroring_Glyph`:

require('unicode-9.0.0/Bidi_Mirroring_Glyph').get(codePoint); // lookup map

// `Bidi_Paired_Bracket_Type`:

require('unicode-9.0.0/Bidi_Paired_Bracket_Type').get(codePoint); // lookup map

require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Close/code-points');
require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Close/symbols');
require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Close/regex');

require('unicode-9.0.0/Bidi_Paired_Bracket_Type/None/code-points');
require('unicode-9.0.0/Bidi_Paired_Bracket_Type/None/symbols');
require('unicode-9.0.0/Bidi_Paired_Bracket_Type/None/regex');

require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Open/code-points');
require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Open/symbols');
require('unicode-9.0.0/Bidi_Paired_Bracket_Type/Open/regex');
```

## Author

| [![twitter/mathias](https://gravatar.com/avatar/24e08a9ea84deb17ae121074d0f17125?s=70)](https://twitter.com/mathias "Follow @mathias on Twitter") |
|---|
| [Mathias Bynens](https://mathiasbynens.be/) |

## License

This module is available under the [MIT](https://mths.be/mit) license.

Written by Radovan Garabík <garabik @ kassiopeia.juls.savba.sk>.
For new versions, look at http://kassiopeia.juls.savba.sk/~garabik/software/unicode/

-------------------

paracode exploits the full power of the Unicode standard to convert the
text into visually similar stream of glyphs, while using completely
different codepoints. It is an excellent didactic tool demonstrating the
principles and advanced use of the Unicode standard. paracode is a
command line tool working as a filter, reading standard input in UTF-8
encoding and writing to standard output.

Use optional -t switch to select what tables to use.

Special name 'all' selects all the tables.

Note that selecting 'other', 'cyrillic_plus' and 'cherokee' tables (and
'all') makes use of rather esoteric characters, and not all fonts
contain them.

Special table 'mirror' uses quite different character substitution,
is not selected automatically with 'all' and does not work well
with anything except plain ascii alphabetical characters.

Example:

paracode -t cyrillic+greek+cherokee

paracode -t cherokee  <input >output

paracode -r -t mirror  <input >output


Possible tables are:

cyrillic

cyrillic_plus

greek

other

cherokee

all

## Full Case Mappings.
## See Unicode 3.13.

## Use the map from SpecialCasing.txt, plus the maps from
## UnicodeData.txt, excluding any of the latter mappings that would
## conflict.  Any character that does not have a mapping in these files
## is considered to map to itself.

## <FIXME>
## For now, only use the unconditional maps in SpecialCasing.txt.
## Add arguments allowing for conditional maps eventually ...
## </FIXME>

u_to_lower_case <-
function(x)
    UseMethod("u_to_lower_case")

u_to_lower_case.u_char <-
function(x)
{
    y <- as.list(x)
    ## Maps from SpecialCasing.txt first.
    p <- match(x, UCD_special_casing_table$Code, 0L)
    p[p > 0L][nzchar(UCD_special_casing_table$Condition[p])] <- 0L
    y[p > 0L] <- UCD_special_casing_table$Lower[p]
    ## Maps from UnicodeData.txt not excluded by the above.
    q <- match(x, UCD_Unicode_data_table$Code, 0L)
    q[p > 0L] <- 0L
    r <- UCD_Unicode_data_table$Simple_Lowercase_Mapping[q]
    ind <- nzchar(r)
    y[q > 0L][ind] <- r[ind]

    as.u_char_seq(y)
}

u_to_lower_case.u_char_range <-
function(x)
    u_to_lower_case(as.u_char_seq(x))

u_to_lower_case.u_char_seq <-
function(x)
    as.u_char_seq(lapply(unclass(x),
                         function(e)
                         unlist(u_to_lower_case(e))))

u_to_lower_case.default <-
function(x)
{
    y <- lapply(x,
                function(s)
                intToUtf8(unlist(u_to_lower_case(.str_to_u_char(s)))))
    as.character(unlist(y))
}

u_to_upper_case <-
function(x)
    UseMethod("u_to_upper_case")

u_to_upper_case.u_char <-
function(x)
{
    y <- as.list(x)
    ## Maps from SpecialCasing.txt first.
    p <- match(x, UCD_special_casing_table$Code, 0L)
    p[p > 0L][nzchar(UCD_special_casing_table$Condition[p])] <- 0L
    y[p > 0L] <- UCD_special_casing_table$Upper[p]
    ## Maps from UnicodeData.txt not excluded by the above.
    q <- match(x, UCD_Unicode_data_table$Code, 0L)
    q[p > 0L] <- 0L
    r <- UCD_Unicode_data_table$Simple_Uppercase_Mapping[q]
    ind <- nzchar(r)
    y[q > 0L][ind] <- r[ind]

    as.u_char_seq(y)
}

u_to_upper_case.u_char_range <-
function(x)
    u_to_upper_case(as.u_char_seq(x))

u_to_upper_case.u_char_seq <-
function(x)
    as.u_char_seq(lapply(unclass(x),
                         function(e)
                         unlist(u_to_upper_case(e))))

u_to_upper_case.default <-
function(x)
{
    y <- lapply(x,
                function(s)
                intToUtf8(unlist(u_to_upper_case(.str_to_u_char(s)))))
    as.character(unlist(y))
}

u_to_title_case <-
function(x)
    UseMethod("u_to_title_case")

u_to_title_case.u_char <-
function(x)
{
    y <- as.list(x)
    ## Maps from SpecialCasing.txt first.
    p <- match(x, UCD_special_casing_table$Code, 0L)
    p[p > 0L][nzchar(UCD_special_casing_table$Condition[p])] <- 0L
    y[p > 0L] <- UCD_special_casing_table$Title[p]
    ## Maps from UnicodeData.txt not excluded by the above.
    q <- match(x, UCD_Unicode_data_table$Code, 0L)
    q[p > 0L] <- 0L
    r <- UCD_Unicode_data_table$Simple_Titlecase_Mapping[q]
    ind <- nzchar(r)
    y[q > 0L][ind] <- r[ind]

    as.u_char_seq(y)
}

## No other methods for now:
## For strings, we must find the word boundaries according to UAX #29
## "Unicode Text Segmentation", and then map characters following the
## word boundaries to their titlecase mapping, and the others to their
## lowercase mapping.


## Case folding.
## See Unicode 3.13.

## <FIXME>
## Add a status/mode argument eventually.
## For now, perform full case folding using mappings with status C and F.
u_case_fold <-
function(x)
    UseMethod("u_case_fold")
## </FIXME>

u_case_fold.u_char <-
function(x)
{
    y <- as.list(x)
    p <- match(x, UCD_case_folding_table$Code, 0L)
    p[(p > 0L) &
      is.na(match(UCD_case_folding_table$Status[p], c("C", "F")))] <- 0L
    y[p > 0L] <- UCD_case_folding_table$Mapping[p]

    as.u_char_seq(y)
}

u_case_fold.u_char_range <-
function(x)
    u_case_fold(as.u_char_seq(x))

u_case_fold.u_char_seq <-
function(x)
    as.u_char_seq(lapply(unclass(x),
                         function(e)
                         unlist(u_case_fold(e))))

u_case_fold.default <-
function(x)
{
    y <- lapply(x,
                function(s)
                intToUtf8(unlist(u_case_fold(.str_to_u_char(s)))))
    as.character(unlist(y))
}           

u_blocks <-
function(x)
{
    if(missing(x)) return(UCD_blocks)
    x <- .expand_property_value_aliases(x, "Block")
    ## When comparing block names, casing, whitespace, hyphens, and
    ## underbars are ignored.
    .canonicalize <- function(s)
        tolower(gsub("[ _-]", "", s))
    
    UCD_blocks[match(.canonicalize(x), .canonicalize(names(UCD_blocks)))]
}

## u_blocks <-
## function(x, drop = TRUE)
## {
##     if(missing(x)) return(UCD_blocks)
##     y <- UCD_blocks[.expand_property_value_aliases(x, "Block")]
##     if((length(y) == 1L) && drop)
##         y <- y[[1L]]
##     y
## }

u_named_sequences <-
function()    
    UCD_named_sequences

u_scripts <-
function(x)
{
    if(missing(x)) return(UCD_scripts)
    UCD_scripts[.expand_property_value_aliases(x, "Script")]
}

## u_scripts <-
## function(x)
## {
##     if(missing(x)) return(UCD_scripts)
##     y <- UCD_scripts[.expand_property_value_aliases(x, "Script")]
##     if((length(y) == 1L) && drop)
##         y <- y[[1L]]
##     y
## }


## Utilities

.expand_property_aliases <-
function(x)
{
    p <- match(x, names(UCD_property_aliases_hash), 0L)
    x[p > 0L] <- UCD_property_aliases_hash[p]
    x
}
    
.expand_property_value_aliases <-
function(x, which)
{
    if(length(which <- as.character(which)) != 1L)
        stop(gettextf("Invalid '%s' argument.", "which"),
             domain = NA)
    which <- .expand_property_aliases(which)
    hash <- UCD_property_value_aliases_hash_list[[which]]
    p <- match(x, names(hash), 0L)
    x[p > 0L] <- hash[p]
    x
}

Unicode_alphabetic_tokenizer <-
function(x)
{
    x <- .str_to_u_char(paste(x, collapse = "\n"))
    x[u_char_property(x, "Alphabetic") == "No"] <- 32L
    unlist(strsplit(intToUtf8(x), " +"))
}

.str_to_u_char <-
function(x)
{
    x <- as.character(x)
    if(length(x) > 1L) {
        if(any(nchar(x) != 1L))
            stop("Invalid 'x'.")
        x <- paste(x, collapse = "")
    }
    if(Encoding(x) == "latin1")
        x <- iconv(x, from = "latin1", to = "UTF-8")
    x <- if(is.na(x))
        NA_integer_
    else
        utf8ToInt(x)
    as.u_char(x)
}

u_char_decomposition <-
function(x)
{
    ## For now, this really gives the Decomposition_Mapping property.
    ## Ideally, this should have a type argument controlling whether to
    ## perform canonical or compatibility decomposition, and most likely
    ## also an argument controlling whether to decompose recursively or
    ## not.

    ## Maybe return a u_char_seq eventually?
    
    x <- as.u_char(x)
    ## Could make this more efficient eventually ...
    p <- match(x, UCD_Unicode_data_table$Code)
    y <- sub(".*> *", "", UCD_Unicode_data_table$Decomposition[p])
    p <- which(is.na(p))
    if(length(p)) {
        r <- u_char_match(x[p], UCD_Unicode_data_range$Range, 0L)
        ind <- (r == UCD_Unicode_data_range_pos_Hangul)
        if(any(ind)) {
            pos <- p[ind]
            y[pos] <-
                gsub("U+", "",
                     vapply(unclass(.u_char_decomposition_Hangul(x[pos])),
                            paste, "", collapse = " "),
                     fixed = TRUE)
        }
        ind <- (r > 0L) & (r != UCD_Unicode_data_range_pos_Hangul)
        if(any(ind)) {
            y[p[ind]] <- ""
        }
    }
    y
}

.u_char_decomposition_Hangul <-
function(s)
{
    y <- rep.int(list(integer()), length(s))
    s <- s - Jamo_S_base
    ok <- (s >= 0) & (s < Jamo_S_count)
    if(any(ok)) {
        s <- s[ok]
        L <- Jamo_L_base + s %/% Jamo_N_count
        V <- Jamo_V_base + (s %% Jamo_N_count) %/% Jamo_T_count
        T <- Jamo_T_base + s %% Jamo_T_count
        y[ok] <- Map(c, L, V, ifelse(T == Jamo_T_base, list(NULL), T))
    }
    as.u_char_seq(y)
}

u_char_from_name <-
function(x, type = c("exact", "grep"), ...)
{
    x <- as.character(x)
    type <- match.arg(type)
    if(type == "exact") {
        ## Matching could/should be less strict ...    
        p <- match(x, UCD_Unicode_data_table$Name)
        y <- UCD_Unicode_data_table$Code[p]
        if(any(is.na(p))) {
            re <- "^HANGUL SYLLABLE *([^AEIOUWY]*)([AEIOUWY]+)([^AEIOUWY]*)$"
            if(length(p <- grep(re, x)))
                y[p] <- .u_char_from_name_Hangul(x[p])
            re <- "^CJK UNIFIED IDEOGRAPH ([0123456789ABCDEF]{4,6})$"
            p <- grep(re, x)
            if(length(p)) {
                u <- as.u_char(sub(re, "\\1", x[p]))
                ## Range check.
                p <- p[u %uin% UCD_Unicode_data_range$Range[1L : 4L]]
                y[p] <- u[p]
            }
        }
    } else {
        ## Currently, no support for Hangul syllable and CJK unified
        ## ideographs ...
        y <- with(UCD_Unicode_data_table,
                  Code[grepl(x, Name, ...)])
    }
        
    y
}

.u_char_from_name_Hangul <-
function(s)
{
    y <- rep.int(NA_integer_, length(s))
    re <- "^HANGUL SYLLABLE *([^AEIOUWY]*)([AEIOUWY]+)([^AEIOUWY]*)$"
    ok <- grepl(re, s)
    if(any(ok)) {
        s <- s[ok]
        L <- sub(re, "\\1", s)
        V <- sub(re, "\\2", s)
        T <- sub(re, "\\3", s)
        ## Seems we cannot subscript with an empty character string:
        y[ok] <- (Jamo_S_base
                  + (match(L, Jamo$L) - 1L) * Jamo_N_count
                  + (match(V, Jamo$V) - 1L) * Jamo_T_count
                  + (match(T, Jamo$T) - 1L)
                  )
    }
    as.u_char(y)
}

u_char_info <-
function(x)
{
    x <- as.u_char(x)
    ## Could make this more efficient eventually ...
    p <- match(x, UCD_Unicode_data_table$Code)
    y <- UCD_Unicode_data_table[p, ]
    row.names(y) <- NULL
    p <- which(is.na(p))
    if(length(p)) {
        r <- u_char_match(x[p], UCD_Unicode_data_range$Range, 0L)
        q <- p[r == UCD_Unicode_data_range_pos_Hangul]
        p <- p[r > 0L]
        y[p, ] <- UCD_Unicode_data_range[r, -1L]
        ## Not quite efficient ...
        y$Name[p] <- u_char_name(x[p])
        ## Call directly for efficiency ...
        y$Decomposition[q] <-
            format(.u_char_decomposition_Hangul(x[q]))
    }
    y
}

u_char_inspect <-
function(x)
{
    x <- as.u_char(x)
    data.frame(Code = x,
               Name = u_char_name(x),
               Char = intToUtf8(x, multiple = TRUE),
               stringsAsFactors = FALSE)
}

u_char_label <-
function(x)
{
    x <- as.u_char(x)
    ## Use the name by default.
    y <- u_char_name(x)
    ## Need to special case the ones with empty or missing names.
    p <- which(is.na(y) | (y == ""))
    if(length(p)) {
        ## Handle surrogate, private use and control characters.
        r <- u_char_match(x[p], 
                          c(UCD_Unicode_data_range$Range[-(1L : UCD_Unicode_data_range_pos_Hangul)],
                            "0000..001F", "007F..009F"),
                          0L)
        ## <FIXME>
        ## This hard-wires the positions of surrogate and private use
        ## character ranges.  Ideally, we would compute these (e.g.,
        ## from the rownames of UCD_Unicode_data_range).
        ## </FIXME>
        q <- p[(r > 0L) & (r <= 3L)]
        y[q] <- sprintf("surrogate-%04X", x[q])
        q <- p[(r > 3L) & (r <= 6L)]
        y[q] <- sprintf("private-use-%04X", x[q])
        q <- p[(r > 6L) & (r <= 8L)]
        y[q] <- sprintf("control-%04X", x[q])
        ## This leaves non-characters and reserved code points.
        q <- p[r == 0L]
        if(length(q)) {
            y[q] <-
                ifelse(u_char_property(x[q],
                                       "Noncharacter_Code_Point") ==
                       "Yes",
                       sprintf("noncharacter-%04X", x[q]),
                       sprintf("reserved-%04X", x[q]))
        }
    }
        
    y
}

u_char_name <-
function(x)
{
    x <- as.u_char(x)
    ## Could make this more efficient eventually ...
    p <- match(x, UCD_Unicode_data_table$Code)
    y <- UCD_Unicode_data_table$Name[p]
    p <- which(is.na(p))
    if(length(p)) {
        range <- UCD_Unicode_data_range$Range
        nomatch <- length(range) + 1L
        r <- u_char_match(x[p], range, nomatch)
        ph <- UCD_Unicode_data_range_pos_Hangul
        ind <- r < ph                   # CJK
        if(any(ind)) {
            pos <- p[ind]
            y[pos] <- .u_char_name_CJK(x[pos])
        }
        ind <- r == ph                  # Hangul
        if(any(ind)) {
            pos <- p[ind]
            y[pos] <- .u_char_name_Hangul(x[pos])
        }
        ind <- (r > ph) & (r < nomatch)
        if(any(ind)) {
            y[p[ind]] <- ""
        }
    }
    y

}

.u_char_name_CJK <-
function(x)
    sprintf("CJK UNIFIED IDEOGRAPH %04X", x)

.u_char_name_Hangul <-
function(x)
{
    s <- .u_char_decomposition_Hangul(x)
    L <- Jamo$L[vapply(s, `[`, 0, 1L) - Jamo_L_base + 1L]
    V <- Jamo$V[vapply(s, `[`, 0, 2L) - Jamo_V_base + 1L]
    T <- Jamo$T[vapply(s, `[`, 0, 3L) - Jamo_T_base + 1L]
    T[is.na(T)] <- ""
    sprintf("HANGUL SYLLABLE %s%s%s", L, V, T)
}

u_char_property_names <-
function()
    unique(UCD_property_aliases_hash)

u_char_properties <-
function(x, which)
{
    if(nargs() == 0L) {
        ## As a convenience, list available properties if no arguments
        ## were given.
        return(sort(intersect(u_char_property_names(),
                              c(names(UCD_Unicode_data_table),
                                names(u_char_property_db),
                                names(u_char_property_getter_db)))))
    }
    
    x <- as.u_char(x)
    which <- .expand_property_aliases(as.character(which))
    all_property_names <- u_char_property_names()
    p <- match(which, all_property_names)
    if(any(ina <- is.na(p))) {
        warning(gettextf("Cannot map %s to Unicode properties",
                         paste(which[ina], collapse = ", ")),
                domain = NA)
        which <- which[!ina]
        p <- p[!ina]
    }

    ## Start with an empty data frame.
    y <- data.frame(x)[-1L]
    if(!any(duplicated(x)))
        row.names(y) <- x
    if(!length(which)) return(y)
    
    UCD_Unicode_data_table_names <- names(UCD_Unicode_data_table)
    p <- match(which, UCD_Unicode_data_table_names, 0L)
    if(any(p > 0L))
        y <- u_char_info(x)[p]
    ## Everything else would need to come from the property db
    p <- match(which, names(u_char_property_db), 0L)
    for(i in which(p > 0L))
        y[[which[i]]] <-
            .u_char_property_from_property_db(x, which[i])
    ## or the property getter db.
    p <- match(which, names(u_char_property_getter_db), 0L)
    for(i in which(p > 0L))
        y[[which[i]]] <- u_char_property_getter_db[[p[i]]](x)

    if(length(bad <- setdiff(which, names(y)))) {
        warning("Obtaining the following properties is not yet implemented:\n",
                strwrap(paste(bad, collapse = ", "),
                        indent = 4L, exdent = 4L))
        for(b in bad) y[[b]] <- rep.int(NA_character_, length(x))
    }

    y[match(which, names(y))]
}
    
u_char_property_getter_db <- list()

u_char_property_getter_db$Decomposition_Mapping <-
    u_char_decomposition

u_char_property <-
function(x, which)
{
    if(length(which <- as.character(which)) != 1L)
        stop(gettextf("Invalid '%s' argument.", "which"),
             domain = NA)
    u_char_properties(x, which)[[1L]]
}

.u_char_property_from_property_db <-
function(x, which)
{
    db <- u_char_property_db[[which]]
    y <- rep.int(db$Default, length(x))
    p <- u_char_match(x, db$Table[[1L]], 0L)
    y[p > 0L] <- db$Table[[2L]][p]
    .expand_property_value_aliases(y, which)
}

u_char_show_glyph <-
function(x)
{
    x <- as.u_char(x)
    ## For now we can only show one glyph at a time ...
    l <- length(x)
    if(l == 0L)
        message("Nothing to show.")
    else if(l > 1L) {
        message("Can only show one glyph.")
        x <- x[1L]
    }
    browseURL(sprintf("http://www.unicode.org/cgi-bin/refglyph?24-%04x",
                      x))
}
    
## See Section 3.12 of the Unicode Standard.

Jamo <-
    list(L =
         ## Initial (HANGUL CHOSEONG)
         c("G", "GG", "N", "D", "DD", "R", "M", "B", "BB", "S", "SS",
           "", "J", "JJ", "C", "K", "T", "P", "H"),
         V =
         ## Medial  (HANGUL JUNGSEONG)
         c("A", "AE", "YA", "YAE", "EO", "E", "YEO", "YE", "O", "WA",
           "WAE", "OE", "YO", "U", "WEO", "WE", "WI", "YU", "EU", "YI",
           "I"),
         T =
         ## Final   (HANGUL JONGSEONG)
         c("", "G", "GG", "GS", "N", "NJ", "NH", "D", "L", "LG", "LM",
           "LB", "LS", "LT", "LP", "LH", "M", "B", "BS", "S", "SS",
           "NG", "J", "C", "K", "T", "P", "H"))


Jamo_S_base <- hex("AC00")
Jamo_L_base <- hex("1100")
Jamo_V_base <- hex("1161")
Jamo_T_base <- hex("11A7")
Jamo_S_count <- 11172L
Jamo_L_count <- 19L
Jamo_V_count <- 21L
Jamo_T_count <- 28L
Jamo_N_count <- Jamo_V_count * Jamo_T_count

## A simple class for Unicode characters, mostly for printing ...

as.u_char <-
function(x) {
    if(inherits(x, "u_char"))
        return(x)
    if(inherits(x, "u_char_seq"))
        x <- unlist(unclass(x))
    else if(inherits(x, "u_char_range"))
        x <- unlist(lapply(unclass(x), function(e)
                           if(length(e) == 1L) e else seq.int(e[1L], e[2L]))
                    )
    if(is.double(x) && all(x == as.integer(x)))
        x <- as.integer(x)
    if(is.character(x))
        x <- hex(sub("^U\\+", "", x))
    if(is.integer(x) && all(is.na(x) | ((x >= 0L) & (x <= U_max))))
        return(.structure(x, class = "u_char"))
    stop("'x' cannot be coerced to u_char.")
}

`[.u_char` <-
function(x, i)
{
    cl <- oldClass(x)
    y <- NextMethod("[")
    oldClass(y) <- cl
    y
}

as.character.u_char <-
function(x, ...)
    format.u_char(x)

as.data.frame.u_char <-
    as.data.frame.vector

as.integer.u_char <-
function(x, ...)
    unclass(x)

as.list.u_char <-
function(x, ...)
    lapply(seq_along(x), function(i) x[i])

c.u_char <-
function(..., recursive = FALSE)
{
    as.u_char(unlist(lapply(list(...), as.u_char)))
}

format.u_char <-
function(x, ...)
{
    if(!length(x)) return(character())
    ifelse(is.na(x), "<NA>", sprintf("U+%04X", x))
}

print.u_char <-
function(x, ...)
{
    print(noquote(format(x)), ...)
    invisible(x)
}

rep.u_char <-
function(x, times, ...)
    as.u_char(NextMethod("rep"))

unique.u_char <-
function(x, incomparables = FALSE, ...)
    as.u_char(NextMethod("unique"))

## A simple class for Unicode character ranges.

## Using a Lo/Hi data frame might be more efficient, but seems tricky to
## get right ...

as.u_char_range <-
function(x)
{
    if(inherits(x, "u_char_range"))
        return(x)
    if(inherits(x, "u_char"))
        return(.structure(split(x, seq_along(x)),
                          class = "u_char_range"))
    ## <FIXME>
    ## Add more checking eventually:
    ##   We should really have length one or two, and in the latter case
    ##   elements should be sorted ...
    ## </FIXME>
    if(is.character(x)) {
        return(.structure(lapply(strsplit(x, "..", fixed = TRUE),
                                 as.u_char),
                          class = "u_char_range"))
    }
    stop("'x' cannot be coerced to u_char_range.")
}

`[.u_char_range` <-
function(x, i)
{
    y <- unclass(x)[i]
    class(y) <- class(x)
    y
}

as.character.u_char_range <-
function(x, ...)
    format.u_char_range(x)

as.data.frame.u_char_range <-
    as.data.frame.vector

## as.list.u_char_range <-
## function(x, ...)
##     lapply(seq_along(x), function(i) x[i])

c.u_char_range <-
function(..., recursive = FALSE)
{
    ## Not quite perfect ...
    as.u_char_range(unlist(lapply(list(...),
                                  function(e)
                                  format(as.u_char_range(e)))))
}

format.u_char_range <-
function(x, ...)
{
    .structure(as.character(vapply(unclass(x), paste, "", collapse = "..")),
               names = names(x))
}
    
print.u_char_range <-
function(x, ...)
{
    print(noquote(format(x)), ...)
    invisible(x)
}

rep.u_char_range <-
function(x, times, ...)
{
    x <- format(x)
    as.u_char_range(NextMethod("rep"))
}

unique.u_char_range <-
function(x, incomparables = FALSE, ...)
{
    x <- format(x)
    as.u_char_range(NextMethod("unique"))
}

unlist.u_char_range <-
function(x, recursive = TRUE, use.names = TRUE)
    as.u_char(x)

## A simple class for Unicode character sequences.

as.u_char_seq <-
function(x, sep = NA_character_)
{
    if(inherits(x, "u_char_seq"))
        return(x)
    if(inherits(x, "u_char_range")) {
        x <- unclass(x)
        ind <- as.logical(lengths(x) == 2L)
        x[ind] <- lapply(x[ind],
                         function(e) as.u_char(seq.int(e[1L], e[2L],
                                                       1L)))
    } else if(is.list(x))
        x <- lapply(x, as.u_char)
    else if(is.character(x)) {
        ## If sep is empty (or has length zero), take "as is".
        ## Otherwise, if sep is not given, use "," if strings start with
        ## "<", and " " otherwise.
        sep <- as.character(sep)
        x <- if(!length(sep) || identical(sep, ""))
            lapply(x, .str_to_u_char)
        else {
            if(is.na(sep)) {
                sep <- rep.int(" +", length(x))
                ind <- grepl("^<.*>$", x)
                x[ind] <- sub("^<(.*)>$", "\\1", x[ind])
                sep[ind] <- ", *"
                lapply(strsplit(x, sep), as.u_char)
            }
            lapply(strsplit(x, sep), as.u_char)
        }
    } else
        stop("'x' cannot be coerced to u_char_seq.")        
    .structure(x, class = "u_char_seq")
}

`[.u_char_seq` <-
function(x, i)
{
    y <- unclass(x)[i]
    class(y) <- class(x)
    y
}

as.character.u_char_seq <-
function(x, ...)
    format.u_char_seq(x)

as.data.frame.u_char_seq <-
    as.data.frame.vector

## as.list.u_char_seq <-
## function(x, ...)
##     lapply(seq_along(x), function(i) x[i])

c.u_char_seq <-
function(..., recursive = FALSE)
{
    as.u_char_seq(unlist(lapply(list(...), as.u_char_seq),
                         recursive = FALSE))
}

format.u_char_seq <-
function(x, ...)
{
    .structure(sprintf("<%s>", vapply(unclass(x), paste, "", collapse = ",")),
               names = names(x))
}
    
print.u_char_seq <-
function(x, ...)
{
    print(noquote(format(x)), ...)
    invisible(x)
}

rep.u_char_seq <-
function(x, times, ...)
    as.u_char_seq(NextMethod("rep"))

unique.u_char_seq <-
function(x, incomparables = FALSE, ...)
    as.u_char_seq(NextMethod("unique"))

unlist.u_char_seq <-
function(x, recursive = TRUE, use.names = TRUE)
    as.u_char(x)

## A generic for counting the number of Unicode characters in Unicode
## character data objects.

n_of_u_chars <-
function(x)
    UseMethod("n_of_u_chars")

n_of_u_chars.u_char <-
function(x)
    length(x)

n_of_u_chars.u_char_range <-
function(x)
{
    if(!length(x)) return(integer())
    mat <- do.call(cbind, lapply(unclass(x), range))
    mat[2L, ] - mat[1L, ] + 1L
}

n_of_u_chars.u_char_seq <-
function(x)
    as.integer(lengths(unclass(x)))

## A helper function for turning hex codes to integers.

hex <- 
function(x)
{
    y <- rep.int(NA_integer_, length(x))
    ind <- nzchar(x)
    y[ind] <- strtoi(x[ind], 16L)
    y
}

## Unicode codespace ranges from U+0000 to U+10FFFF.
U_max <- hex("10FFFF")

## Matching

u_char_match <-
function(x, table, nomatch = NA_integer_)
{
    ## Match u_char x against a u_char_range table.
    x <- as.u_char(x)
    table <- unclass(as.u_char_range(table))
    y <- rep.int(nomatch, length(x))
    ## <FIXME>
    ## Maybe eventually "improve" by handling the length one cases
    ## directly, but even
    lens <- lengths(table)
    ## takes a lot of time.
    ## Remember that we decided not to use a lo/hi matrix representation
    ## for u_char_range objects because getting this into a data frame
    ## did not work ...
    hpos <- cumsum(lens)
    lpos <- 1L + c(0L, hpos[-length(hpos)])
    cps <- unlist(table)
    lo <- cps[lpos]
    hi <- cps[hpos]
    pos <- which(outer(x, lo, `>=`) & outer(x, hi, `<=`),
                 arr.ind = TRUE)
    ind <- seq_len(nrow(pos))
    y[pos[ind, 1L]] <- pos[ind, 2L]
    ## </FIXME>
    y
}

`%uin%` <-
function(x, table)
    u_char_match(x, table, nomatch = 0L) > 0L

## Internal stuff.

.structure <-
function(x, ...)
    `attributes<-`(x, c(attributes(x), list(...)))

\name{u_char_properties}
\alias{u_char_info}
\alias{u_char_property}
\alias{u_char_properties}
\title{Unicode Character Properties}
\description{
  Get the properties of Unicode characters.
}
\usage{
u_char_info(x)
u_char_properties(x, which)
u_char_property(x, which)
}
\arguments{
  \item{x}{an \R object which can be coerced to a \code{\link{u_char}}
    vector of Unicode characters via \code{\link{as.u_char}}.}
  \item{which}{a character vector or string (for
    \code{u_char_property}), respectively, with the possibly abbreviated
    names of Unicode properties.
  }
}
\value{
  For \code{u_char_info}, a data frame with variables giving the Code
  (\code{Code}) and the \sQuote{basic} Unicode variables Name, General
  Category, Canonical Combining Class, Bidi Class, Decomposition,
  Numeric Value Decimal Digit, Numeric Value Digit, Numeric Value,
  Bidi Mirrored, Unicode 1 Name, ISO Comment, Simple Uppercase Mapping,
  Simple Lowercase Mapping, and Simple Titlecase Mapping, with names
  obtained by replacing white spaces by underscores (e.g.,
  \code{Bidi_Class}.)

  For \code{u_char_properties}, a data frame with the values of the
  specified properties, or, if no arguments were given, a character
  vector with the names of all currently available Unicode character
  properties.

  For \code{u_char_property}, the values of the specified property.
}
\note{
  Currently, only the property values of a subset of all Unicode
  character properties can be obtained.
}
\references{
  Unicode Character Database (\url{https://www.unicode.org/ucd/})
}
\examples{
## When was the Euro sign added to Unicode?
x <- u_char_from_name("EURO SIGN")
u_char_property(x, "Age")

## List the currently available Unicode character properties.
u_char_properties()
}

\name{u_blocks}
\alias{u_blocks}
\title{Unicode Blocks}
\description{
  Unicode blocks.
}
\usage{
u_blocks(x)
}
\arguments{
  \item{x}{a character vector with the names of Unicode blocks.}
}
\value{
  If \code{x} is missing, a list of the Unicode blocks given as
  \code{\link{u_char_range}} Unicode character ranges, with the (full)
  block names as names.

  If \code{x} is given, a (sub)list of the specific Unicode blocks.
}
\seealso{
  \code{\link{u_char_property}} to find the block (property) of Unicode
  characters.
} 
\references{
  Unicode Character Database (\url{https://www.unicode.org/ucd/})
}

\name{u_scripts}
\alias{u_scripts}
\title{Unicode Scripts}
\description{
  Unicode scripts.
}
\usage{
u_scripts(x)
}
\arguments{
  \item{x}{a character vector with the names of Unicode scripts.}
}
\value{
  If \code{x} is missing, a list of the Unicode scripts given as
  \code{\link{u_char_range}} Unicode character ranges, with the (full)
  block names as names.

  If \code{x} is given, a (sub)list of the specific Unicode scripts.
}
\seealso{
  \code{\link{u_char_property}} to find the script (property) of Unicode
  characters.
} 
\references{
  Unicode Character Database (\url{https://www.unicode.org/ucd/})
}
\examples{
scripts <- u_scripts()
names(scripts)
## Total number of code points assigned to the scripts:
sort(vapply(scripts, function(s) sum(n_of_u_chars(s)), 0),
     decreasing = TRUE)
}

\name{u_named_sequences}
\alias{u_named_sequences}
\title{Unicode Named Sequences}
\description{
  Unicode named sequences.
}
\usage{
u_named_sequences()
}
\value{
  A data frame with elements \code{Name} and \code{Sequence} giving the
  names and the corresponding Unicode character sequences.
}

\name{u_char_basics}
\alias{as.u_char}
\alias{as.u_char_range}
\alias{as.u_char_seq}
\alias{u_char}
\alias{u_char_range}
\alias{u_char_seq}
\title{Unicode Character Objects}
\description{
  Data structures and basic methods for Unicode character data.
}
\usage{
as.u_char(x)
as.u_char_range(x)
as.u_char_seq(x, sep = NA_character_)
}
\arguments{
  \item{x}{R objects coercible to the respective Unicode character data
    types, see \bold{Details}.}
  \item{sep}{a character string.}
}
\details{
  Package \pkg{Unicode} provides three basic classes for representing
  Unicode characters: \code{u_char} for vectors of Unicode characters,
  \code{u_char_range} for vectors of Unicode character ranges, and
  \code{u_char_seq} for vectors of Unicode character sequences.  Objects
  from these classes are created via the respective coercion functions.

  \code{as.u_char} knows to coerce integers or hex strings (with or
  without a leading \samp{0x} or the \samp{U+} typically used for
  Unicode characters) giving the corresponding code points.  It can also
  handle Unicode character ranges, flattening them out into the
  corresponding vector of Unicode characters.  To \dQuote{coerce} a
  UTF-8 encoded \R character string to the corresponding Unicode
  character object, use coercion on the result of obtaining the integer
  code points via \code{\link{utf8ToInt}}.

  \code{as.u_char_range} knows to coerce character strings of single
  Unicode characters or a Unicode range expression with the hex codes of
  two Unicode characters collapsed by \samp{..} (currently, hard-wired).
  It can also handle \code{u_char} objects, coercing them to ranges of
  single code points.

  \code{as.u_char_seq} knows to coerce character strings with the hex
  codes of Unicode characters collapsed by a non-empty \code{sep}.  The
  default corresponds to using \samp{,} if the strings use surrounding
  angles, and \samp{ } otherwise.  If \code{sep} is empty or has length
  zero, the character strings are used as is, re-encoded in UTF-8 if
  necessary, and mapped to the corresponding Unicode character sequences
  using \code{\link{utf8ToInt}}.  \code{as.u_char_seq} can also handle
  Unicode character ranges (giving the corresponding flattened out
  Unicode character sequences), or lists of objects coercible to Unicode
  characters via \code{as.u_char}.

  All classes currently have \code{as.character}, \code{as.data.frame},
  \code{c}, \code{format}, \code{print}, \code{rep}, \code{unique} and
  \code{[} subscript methods.  More methods will be added eventually.
}
\value{
  For \code{as.u_char}, a \code{u_char} object giving a vector of
  Unicode characters.

  For \code{as.u_char_range}, a \code{u_char_range} object giving a
  vector of Unicode character ranges.

  For \code{as.u_char_seq}, a \code{u_char_seq} object giving a
  vector of Unicode character sequences.
}
\references{
  Unicode Character Database (\url{https://www.unicode.org/ucd/}),\cr
  \url{https://en.wikipedia.org/wiki/Unicode}
}
\examples{
x <- as.u_char_range(c("00AA..00AC", "01CC"))
x
## Corresponding Unicode character sequence object:
as.u_char_seq(x)
## Corresponding Unicode character object with all code points:
as.u_char(x)
## Inspect all Unicode characters in the range:
u_char_inspect(x)

## Turning R character strings into the respective Unicode character
## sequences:
as.u_char_seq(c("Austria", "Trantor"), "")
## which can then be subscripted "as usual", e.g.:
x <- as.u_char_seq(c("Austria", "Trantor"), "")[[1L]][c(3L, 5L)]
x
## To reassemble the character strings:
intToUtf8(x)
}

\name{u_char_match}
\alias{u_char_match}
\alias{\%uin\%}
\title{Unicode Character Matching}
\description{
  Match Unicode characters to Unicode character ranges.
}
\usage{
u_char_match(x, table, nomatch = NA_integer_)
x \%uin\% table
}
\arguments{
  \item{x}{an \R object which can be coerced to a \code{\link{u_char}}
    vector of Unicode characters via \code{\link{as.u_char}}.}
  \item{table}{an \R object coercible to a \code{\link{u_char_range}}
    vector of Unicode character range via \code{\link{as.u_char_range}}.}
  \item{nomatch}{the value to be returned (after coercion to integer) in
    the case when no match is found.}
}
\details{
  \code{u_char_match} returns a vector of the positions of the (first)
  matches of the Unicode characters given by \code{x} (after coercion
  via \code{\link{as.u_char}}) to the Unicode character ranges given by
  \code{table} (after coercion via \code{\link{as.u_char_range}}).

  \code{\%uin\%} returns a logical vector indicating if there was a
  match or not.
}

\name{tokenizers}
\alias{Unicode_alphabetic_tokenizer}
\title{Unicode Alphabetic Tokenizer}
\description{
  A simple Unicode alphabetic tokenizer.
}
\usage{
Unicode_alphabetic_tokenizer(x)
}
\arguments{
  \item{x}{a character vector.}
}
\details{
  Tokenization first replaces the elements of \code{x} by their Unicode
  character sequences.  Then, the non-alphabetic characters (i.e., the
  ones which do not have the Alphabetic property) are replaced by
  blanks, and the corresponding strings are split according to the
  blanks.
}
\value{
  A character vector with the tokenized strings.
}

\name{casefuns}
\encoding{UTF-8}
\alias{u_to_lower_case}
\alias{u_to_upper_case}
\alias{u_to_title_case}
\alias{u_case_fold}
\title{Unicode Case Conversions}
\description{
  Default Unicode algorithms for case conversion.
}
\usage{
u_to_lower_case(x)
u_to_upper_case(x)
u_to_title_case(x)
u_case_fold(x)
}
\arguments{
  \item{x}{\R objects (see \bold{Details}).}
}
\details{
  These functions are generic functions, with methods for the Unicode
  character classes (\code{\link{u_char}}, \code{\link{u_char_range}},
  and \code{\link{u_char_seq}}) which suitably apply the case mappings
  to the Unicode characters given by \code{x}, and a default method
  which treats \code{x} as a vector of \dQuote{Unicode strings}, and
  returns a vector of UTF-8 encoded character strings with the results
  of the case conversion of the elements of \code{x}.

  Currently, only the unconditional case maps are available for
  conversion to lower, upper or title case: other variants may be added
  eventually.

  Currently, conversion to title case is only available for
  \code{\link{u_char}} objects.  Other methods will be added
  eventually (once the Unicode text segmentation algorithm is
  implemented for detecting word boundaries).

  Currently, \code{u_case_fold} only performs \emph{full} case folding
  using the Unicode case mappings with status \dQuote{C} and \dQuote{F}:
  other variants will be added eventually.
}
\value{
  For the methods for the Unicode character classes, a
  \code{\link{u_char_seq}} vector of Unicode character sequences with 
  the conversions of the characters in \code{x}.

  For the default method, a UTF-8 encoded character string with the
  results of the case conversions of the elements of \code{x}.
}
\examples{
## Latin upper case letters A to Z:
x <- as.u_char(as.u_char_range("0041..005A"))
## In case we did not know the code points, we could use e.g.
x <- as.u_char(utf8ToInt(paste(LETTERS, collapse = "")))
vapply(x, intToUtf8, "")
## Unicode character method:
vapply(u_to_lower_case(x), intToUtf8, "")
## Default method:
u_to_lower_case(LETTERS)

u_case_fold("Hi Dave.")

## More interesting stuff: sharp s.
u_to_upper_case("heiß")
## Note that the default full upper case mapping of U+00DF (LATIN SMALL
## LETTER SHARP S) is *not* to U+1E9E (LATIN CAPITAL LETTER SHARP S).
u_case_fold("heiß")
}

\name{u_char_inspect}
\alias{u_char_inspect}
\title{Unicode Character Inspection}
\description{
  Inspect Unicode characters.
}
\usage{
u_char_inspect(x)
}
\arguments{
  \item{x}{an \R object which can be coerced to a \code{\link{u_char}}
    vector of Unicode characters via \code{\link{as.u_char}}.}
}
\value{
  A data frame with variables \code{Code}, \code{Name} and \code{Char},
  giving the code and name of the given characters and the \R character
  vectors corresponding to the code points.
}
\examples{
## Who has ever seen a capital sharp s?
x <- u_char_from_name(c("LATIN SMALL LETTER SHARP S",
                        "LATIN CAPITAL LETTER SHARP S"))
u_char_inspect(x)
## (Does this display anything useful?)
}

\name{n_of_u_chars}
\alias{n_of_u_chars}
\title{Unicode Character Counts}
\description{
  Compute the number of Unicode characters (code points) in sequences
  or ranges of Unicode characters.
}
\usage{
n_of_u_chars(x)
}
\arguments{
  \item{x}{a vector of Unicode characters, character ranges, or
    character sequences.
  }
}
\value{
  An integer vector with the numbers of Unicode characters specified by
  the elements of \code{x}.
}
\examples{
## How many code points are assigned to the Latin and Cyrillic scripts?
x <- u_scripts(c("Latn", "Cyrl"))
## Numbers in the respective ranges:
n <- lapply(x, n_of_u_chars)
n
## Total number:
vapply(n, sum, 0)
}

\name{u_char_names}
\alias{u_char_name}
\alias{u_char_from_name}
\alias{u_char_label}
\title{Unicode Character Names}
\description{
  Find the names or labels of Unicode characters, or Unicode characters
  by their name.
}
\usage{
u_char_name(x)
u_char_from_name(x, type = c("exact", "grep"), ...)
u_char_label(x)
}
\arguments{
  \item{x}{an \R object which can be coerced to a \code{\link{u_char}}
    vector of Unicode characters via \code{\link{as.u_char}} for
    \code{u_char_name} and \code{u_char_label};
    a character vector otherwise.
  }
  \item{type}{one of \code{"exact"} or \code{"grep"}, or an abbreviation
    thereof.
  }
  \item{...}{arguments to be passed to \code{\link{grepl}} when using
    this for pattern matching.
  }
}
\details{
  The Unicode Standard provides a convention for labeling code points
  that do not have character names (control, reserved, noncharacter,
  private-use and surrogate code points).  These labels can be obtained
  by \code{u_char_label}.
  
  By default, exact matching is used for finding Unicode characters by
  name.  When \code{type = "grep"}, \code{\link{grepl}} is used for
  matching \code{x} against the Unicode character names; for now, Hangul
  syllable and CJK Unified Ideograph names are ignored in this case.
}
\value{
  For \code{u_char_name} and \code{u_char_label}, a character vector
  with the names or labels, respectively, of the corresponding Unicode
  characters.

  For \code{u_char_from_name}, a \code{\link{u_char}} object giving the
  Unicode characters with name exactly matching the given names.
}
\examples{
x <- as.u_char(utf8ToInt("Austria"))
u_char_name(x)

## Derived Hangul syllable character names are also supported for
## finding characters by exact matching:
x <- u_char_name("0xAC00")
x
u_char_from_name(x)

## Find all Unicode characters with name matching 'DIGIT ONE'.
x <- u_char_from_name("\\\\bDIGIT ONE\\\\b", "g")
## And show their names.
u_char_name(x)
}
